/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2004). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC100 with LDO Sensor		   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			Aug 2004			   */
/*	File:			SolitaxMultiunit.ddl			   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/


MANUFACTURER		 26,
DEVICE_TYPE			 1,
DEVICE_REVISION  1,
DD_REVISION			 1

#define DEVICE_TITLE			"Amtax Inter"

#include "SI_FileM.inc"
#include "SI_DevM.inc"
#include "SI_ViewM.inc"
#include "SI_OptM.inc"
//#include "SIPAST.inc"
#include "Diagnosis.inc"

#define YT1_LABEL "Messwert Chart"
#define YT1_VALUE Measurement
#define YT1_LRV   UntererGrenzwert
#define YT1_URV   ObererGrenzwert
#include "SI_YT.inc"



/************************************************************************/
/*		Variablen						*/
/************************************************************************/



VARIABLE Measurement
{
	LABEL 	"Messwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  8.0;
			MIN_VALUE	0;
			MAX_VALUE      20;
        }
	HANDLING	READ;
	//CONSTANT_UNIT "%";
}

VARIABLE Unit
{
	LABEL 	"Unit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"mg/l"	},
			{1,			"g/l"   },
			{2,			"ppm"	},
			{6,			"FNU"   },
			{7,			"NTU"	},
			{8,			"TE/F"  },
			{9,			"EBC"	},
			{10,			"%"  	}
			
			
		}
	HANDLING	READ & WRITE;
}

VARIABLE Parameter
{
	LABEL 	"Measurement Mode";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			{0,			"Turbidity"	},
			{1,			"Suspendet Solids"}
		}
	HANDLING	READ & WRITE;
}

VARIABLE Status
{
	LABEL 	"Status";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
	{
		DEFAULT_VALUE	0;
		{	0,   "Probe detected"		},
		{	1,   "Measurement Valid"	},
		{	2,   "Min Measurement"		},
		{	3,   "Max Measurement"		},
		{	15,  "Common Error"		}
			
	}	
	HANDLING	READ;
}

VARIABLE ErrorA
{
	LABEL 	"ErrorASCII";
	CLASS	CONTAINED;
	TYPE	ASCII (1)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}

VARIABLE Error
{
	LABEL	"Error";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
			{0,	"No error"		},
			{1,	"No tuning"		},
			{2,	"Test settings"		},
			{3,	"Probe not established"	},
			{4,	"Establishing probe manually"	},
			{5,	"Probe connection"	},
			{6,	"Probe faulty"		},
			{7,	"Wrong probe"		},
			{8,	"Humidity"		},
			{9,	"Probesettings"		},
			{10,	"Wiperstatus"		},
			{11,	"Wiper jammed"		},
			{12,	"Wiper blocked"		},
			{13,	"Time out"		},
			{14,	"Wiper unknowen"	},
			{15,	"New wiper profile"	},
			{16,	"Signal too small"	},
			{17,	"EE-Prom fault"		}
	}
	HANDLING	READ;
}

VARIABLE Correction
{
	LABEL 	"Correction";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
}

VARIABLE Offset
{
	LABEL 	"Offset";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
}

VARIABLE Channel_1
{
	LABEL 	"Channel 1";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}

VARIABLE Channel_2
{
	LABEL 	"Channel 2";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}

VARIABLE Integration
{
	LABEL 	"Integration";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE CleaningInterval
{
	LABEL 	"Cleaning interval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"Automatic"		},
		{1,	"15 min."		},
		{2,	"30 min"		},
		{3,	"1 houre"		},
		{4,	"4 houres"		},
		{5,	"12 houres"		},
		{6,	"1 day"			},
		{7,	"3 days"		},
		{8,	"7 days"		},
		{9,	"1 min."		},
		{10,	"5 min."		},
        }
	HANDLING	READ & WRITE;
}

VARIABLE Wiperstatus
{
	LABEL 	"Wiper status";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
	{
		{0,	"wiper park position"	},
		{1,	"run wiper cycle."	}
        }
	HANDLING	READ & WRITE;
}

VARIABLE Wiperprofile
{
	LABEL 	"Wiper replace counter";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
        {
	
        }
	HANDLING	READ;
}

VARIABLE Motorcycles
{
	LABEL 	"Motor counter";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
	        {
		
	        }
	HANDLING	READ;

}

VARIABLE SampleLocation
{
	LABEL 	"Probe Location";
	CLASS	CONTAINED;
	TYPE	ASCII (8)
		{
			DEFAULT_VALUE " ";
		}
	HANDLING	READ & WRITE;
}

VARIABLE ObererGrenzwert
{
	LABEL 	"Hi Limit";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  100.0;
			
        }
	HANDLING	READ;
}

VARIABLE UntererGrenzwert
{
	LABEL 	"Lo Limit";
	CLASS	CONTAINED & DYNAMIC;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  -1.0;
			
        }
	HANDLING	READ;
}

VARIABLE VendorName
{
	LABEL 	"Geraetehersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "Hach-Lange";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Geraetetyp";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "SC100";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Seriennummer";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "123456789";
		}
	HANDLING	READ;
}

VARIABLE func1_AI_out_upper_range_value
{
	LABEL 		[func_upper_value];
	HELP		[func_out_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 140.0;
	}
	HANDLING	READ;
}

VARIABLE func1_AI_out_lower_range_value
{
	LABEL 		[func_lower_value];
	HELP		[func_out_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE -50.0;
	}
	HANDLING	READ & WRITE;
}
/*
VARIABLE func1_AI_out_unit_m
{
	LABEL 		"Masseinheit";
	HELP		[digital_units_help];
	CLASS		CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "  ";
		}
	HANDLING	READ;

}
*/
VARIABLE func1_AI_out_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		INTEGER (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		},
		{	6,   "6"		},
		{	7,   "7"		}
	}
	HANDLING	READ;
}

UNIT Select_unit
{
	Unit:
	Measurement,
	ObererGrenzwert,
	UntererGrenzwert
//	func1_AI_hi_hi_lim,
//	func1_AI_lo_lo_lim
}

VARIABLE func1_AI_hi_hi_lim
{
	LABEL		"ObererGrenzwert";
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	100.0 ;
		MIN_VALUE		-50.0 ;
		MAX_VALUE		750.0 ;
	}
	HANDLING	READ;
}

VARIABLE func1_AI_lo_lo_lim
{
	LABEL		"UntererGrenzwert";
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	  0.0 ;
		MIN_VALUE		-50.0 ;
		MAX_VALUE		750.0 ;
	}
	HANDLING	READ;
}

/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/




COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}

COMMAND read_Measurement
{
	SLOT 1;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Measurement
        }
    }
}

COMMAND read_Unit
{
	SLOT 1;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Unit
        }
    }
}

COMMAND write_Unit
{
	SLOT 1;
	INDEX 4;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              Unit
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_Parameter
{
	SLOT 2;
	INDEX 3;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Parameter
        }
    }
}

COMMAND write_Parameter
{
	SLOT 2;
	INDEX 3;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
            Parameter
        }
                REPLY
        {
            
        }
    }
}

COMMAND read_Status
{
	SLOT 2;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Status
        }
    }
}

COMMAND read_Error
{
	SLOT 2;
	INDEX 5;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Error
        }
    }
}

COMMAND read_Correction
{
	SLOT 2;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Correction
        }
    }
}

COMMAND write_Correction
{
	SLOT 2;
	INDEX 6;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Correction
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_Offset
{
	SLOT 2;
	INDEX 8;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Offset
        }
    }
}

COMMAND write_Offset
{
	SLOT 2;
	INDEX 8;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        	Offset
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_Channel_1
{
	SLOT 2;
	INDEX 45;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Channel_1
        }
    }
}

COMMAND read_Channel_2
{
	SLOT 2;
	INDEX 47;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Channel_2
        }
    }
}

COMMAND read_Integration
{
	SLOT 2;
	INDEX 10;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Integration
        }
    }
}

COMMAND read_CleaningInterval
{
	SLOT 2;
	INDEX 12;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            CleaningInterval
        }
    }
}

COMMAND write_CleaningInterval
{
	SLOT 2;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        CleaningInterval
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_Wiperstatus
{
	SLOT 2;
	INDEX 13;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         0,
         0,
         Wiperstatus  
        }
    }
}

COMMAND write_Wiperstatus
{
	SLOT 2;
	INDEX 13;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Wiperstatus
        }
        REPLY
        {
           
        }
    }
}


COMMAND read_Wiperprofile
{
	SLOT 2;
	INDEX 25;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Wiperprofile
        }
    }
}

COMMAND read_Motorcycles
{
	SLOT 2;
	INDEX 29;
    	OPERATION READ;
    	TRANSACTION
    	{
        REQUEST
        {
        }
        REPLY
        {
            Motorcycles
        }
    }
}

COMMAND read_SampleLocation
{
	SLOT 2;
	INDEX 18;
    	OPERATION READ;
    	TRANSACTION
    	{
        REQUEST
        {
        }
        REPLY
        {
            SampleLocation
        }
    }
}

COMMAND write_SampleLocation
{
	SLOT 2;
	INDEX 18;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        SampleLocation
        }
        REPLY
        {
            
        }
    }
}

/************************************************************************/
/*  Daten lesen vom Gert zum PC					*/
/************************************************************************/

MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{ 
		VendorName,
		ModelName,
		ModelNummer,
		Measurement,
		Unit,
		Parameter,
		Status,
		Error,
		Correction,
		Offset,
		Channel_1,
		Channel_2,
		Integration,
		CleaningInterval,
		Wiperstatus,
		Wiperprofile,
		SampleLocation,
		Motorcycles
	}
} 


/************************************************************************/
/*  Datenschreiben vom PC zum Gert								        */
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
		Offset,
		Correction,
		SampleLocation,
		CleaningInterval,
		Unit,
		Wiperstatus,
		Parameter
	}
}

/************************************************************************/
/*	  Table: Specialist													*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_s_preferences,
		Tab_s_settings,
		Tab_s_diag,
		Tab_s_output
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_S_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR,
		OnlineWindow_range_preferences
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
        OnlineWindow_yt
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU OnlineWindow_range_preferences
{
    LABEL	"Wechseln der Voreinstellungen";
    ITEMS
    {
		Page_range_preferences
    }
}

MENU Page_range_preferences
{
    LABEL	"Voreinstellungen";
    ITEMS
    	{
//		func1_AI_out_unit_m,
							
	}
}

MENU Tab_s_preferences
{
    LABEL	"Overview";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
		SampleLocation


    }
}

MENU Tab_s_output
{
	LABEL		[menu_output];
	ITEMS
	{
		Measurement,
		func1_AI_lo_lo_lim,
		func1_AI_hi_hi_lim

	}
}

MENU Tab_s_diag
{
	LABEL			"Diagnostics";
	ITEMS
	{
		Unit,
		Status,
		Parameter,
		Error,
		Channel_1,
		Channel_2,
		Motorcycles,
		Wiperprofile
	}
}

MENU Tab_s_settings
{
	LABEL			"Settings";
	ITEMS
	{
		Offset,
		Correction,
		Integration,
		CleaningInterval,
		Wiperstatus,
		Parameter
		
	}
}


/************************************************************************/
/*	  Table: Maintenance												*/
/************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_m_preferences,
		Tab_m_output,
		Tab_m_settings,
		Tab_m_diag
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        //Menu_M_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_M_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_M_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
        OnlineWindow_yt
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU Tab_m_preferences
{
    LABEL			"Overview";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
		SampleLocation
		

    }
}

MENU Tab_m_output
{
	LABEL			"Measurement";
	ITEMS
	{
		Measurement,
		Parameter,
		Status
	}
}

MENU Tab_m_diag
{
	LABEL			"Diagnostics";
	ITEMS
	{
		Error,
		Status,
		Parameter,
		Channel_1,
		Channel_2,
		Wiperprofile,
		Motorcycles
	}
}


MENU Tab_m_settings
{
	LABEL			"Settings";
	ITEMS
	{
		Offset,
		Correction,
		Integration,
		CleaningInterval,
		Wiperstatus
	
	}
}

MENU OnlineWindow_actual_mode
{
	LABEL			"Aktueller Modus";
	ITEMS
	{
		Parameter	(READ_ONLY)


	}
}

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_func1
	}
}

MENU Page_display_func1
{
	LABEL       "Measured Value" ;
	ITEMS
	{
		BarVal_out_display_func1
	}
}


MENU BarVal_out_display_func1
{
	LABEL		[func_out_value];
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		Measurement				(READ_ONLY),
		func1_AI_out_lower_range_value		(READ_ONLY),
		func1_AI_out_upper_range_value		(READ_ONLY)
	}
}


