/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2005). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			Phosphax Sigma		           */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			July 2005			   */
/*	File:			PhosphaxSigma.ddl		   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/


MANUFACTURER		 128,
DEVICE_TYPE			 1,
DEVICE_REVISION  1,
DD_REVISION			 1

#define DEVICE_TITLE			"Phosphax Sigma"

#include "SI_FileM.inc"
#include "SI_DevM.inc"
#include "SI_ViewM.inc"
#include "SI_OptM.inc"
//#include "SIPAST.inc"
#include "Diagnosis.inc"

//#define YT1_LABEL "Current Value"	"|de|aktueller Messwert"
//#define YT1_VALUE Measurement
//#define YT1_LRV   UntererGrenzwert
//#define YT1_URV   ObererGrenzwert

//#define YT2_LABEL "Current Temperature"	"|de|aktuelle Temperatur"
//#define YT2_VALUE Temp
//#define YT2_URV   UntererGrenzwert
//#define YT2_LRV   ObererGrenzwert
//#include "SI_YT.inc"



/************************************************************************/
/*		Variablen						*/
/************************************************************************/



VARIABLE Measurement
{
	LABEL 	"Measured Value GP"	"|de|Messwert GP";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE 0.0;
			MIN_VALUE	0;
			MAX_VALUE     100;
        }
	HANDLING	READ;
	DISPLAY_FORMAT ".2f";
	//CONSTANT_UNIT "mg/l";
}

VARIABLE Measurement_OR
{
	LABEL 	"Measured Value OR"	"|de|Messwert OR";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE 0.0;
			MIN_VALUE	0;
			MAX_VALUE     100;
        }
	HANDLING	READ;
	DISPLAY_FORMAT ".2f";
	//CONSTANT_UNIT "mg/l";
}

VARIABLE Unit
{
	LABEL 	"Unit"			"|de|Einheit";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{0,			"mg/l"	}
				
		}
	HANDLING	READ ;
}

VARIABLE Parameter
{
	LABEL 	"Measurement Mode GP"	"|de|Messparameter GP";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			{13,			"P"	}
		}
	HANDLING	READ ;
}

VARIABLE Parameter_OR
{
	LABEL 	"Measurement Mode OR"	"|de|Messparameter OR";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			{15,			"PO4-P"	}
		}
	HANDLING	READ ;
}

VARIABLE Status
{
	LABEL 	"Status"		"|de|Status";
	CLASS	DYNAMIC;
	TYPE	BIT_ENUMERATED (2)
	{
		{0,   	"OK"						"|de|OK"	 		 },
		{1,   	"Calibration start / in progress"		"|de|Kalibrierung aktiv"	 },
		{2,   	"Cleaning start / in progress"			"|de|Reinigungszyklus aktiv"	 },
		{4,   	"Enter(d) Service/Maintenance menu"		"|de|Betriebsart Service"	 },
		{8,   	"Common Error"					"|de|Sammelstrung"		 },
		{16,   	"Measurement 0 Quality Bad"			"|de|Messung 0 Qualittsfehler"	 },
		{32,   	"Measurement 0 low limit"			"|de|Messung 0 unterer Grenzwert"},
		{64,    "Measurement 0 high limit"			"|de|Messung 0 oberer Grenzwert" },
		{128,   "Measurement 1 Quality Bad"			"|de|Messung 1 Qualittsfehler"	 },
		{256,   "Measurement 1 low limit"			"|de|Messung 1 unterer Grenzwert"},
		{512,   "Measurement 1 high limit"			"|de|Messung 1 oberer Grenzwert" },
		{1024,  "Measurement 2 Quality Bad"			"|de|Messung 2 Qualittsfehler"	 },
		{2048,  "Measurement 2 low limit"			"|de|Messung 2 unterer Grenzwert"},	
		{4096,  "Measurement 2 high limit"			"|de|Messung 2 oberer Grenzwert" },
		{8192,  "Measurement 3 Quality Bad"			"|de|Messung 3 Qualittsfehler"	 },
		{16384, "Measurement 3 low limit"			"|de|Messung 3 unterer Grenzwert"},
		{32768, "Measurement 3 high limit"			"|de|Messung 3 oberer Grenzwert" }
		
		
	}	
	HANDLING	READ;
}

VARIABLE ErrorA
{
	LABEL 	"ErrorASCII";
	CLASS	CONTAINED;
	TYPE	ASCII (1)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ;
}


VARIABLE ErrorClasses
{
	LABEL	"Error Classes"		"|de|Fehlerklassen";
	CLASS	CONTAINED;
	TYPE	BIT_ENUMERATED (2)
	{
			{0,   	"No Error"				"|de|Kein Fehler"			},
			{1,   	"Measurement calibration Error"		"|de|Kalibrierfehler"			},
			{2,   	"Electronic adjustment Error"		"|de|Elektronik / Einstellfehler"	},
			{4,   	"Cleaning Error"			"|de|Reinigungsfehler"			},
			{8,   	"Measuring module Error"		"|de|Messmodulfehler"			},
			{16,   	"Settings Error"			"|de|Fehler Einstellungen"		},
			{32,   	"Hardware Error"			"|de|Hardwarefehler"			},
			{64,    "Internal communication Error"		"|de|Interner Kommunikationsfehler"	},
			{128,   "Humidity Error"			"|de|Feuchtigkeit erkannt"		},
			{256,   "Temperatur Error"			"|de|Temperaturfehler"			},
			{512,   ""										},
			{1024,  ""										},
			{2048,  ""										},	
			{4096,  "Questionable measurement Warning"	"|de|Warnung Messwert unsicher"		},
			{8192,  "Safety Warning"			"|de|Warnung Sicherheitseinrichtung"	},
			{16384, "Reagent Warning"			"|de|Warnung Reagenz"			},
			{32768, "Maintenance Warning"			"|de|Warnung Instandhaltung"		}
					
	}
	HANDLING	READ;
}


VARIABLE Error
{
	LABEL	"Error"			"|de|Fehler";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
			{0,	"No error"				"|de|Kein Fehler"			},
			{1,	"No tuning"				"|de|Keine Einstelldaten"		},
			{2,	"Test settings"				"|de|Testbetrieb"			},
			{3,	"security window not closed"		"|de|Sicherheitsabdeckung offen"	},
			{4,	"humidity"				"|de|Feuchtigkeit erkannt"		},
			{5,	"internal buserror"			"|de|interner Busfehler"		},
			{6,	"no reaction (busdevice)"		"|de|keine Reaktion Buskopplung"	},
			{7,	"no reaction (busdevice direct)"	"|de|keine Reaktion Bus direkt"		},
			{8,	"timeout (busdevice)"			"|de|Zeitberschreitung Buskopplung"	},
			{9,	"timeout process"			"|de|Zeitberschreitung Prozess"	},
			{10,	"positioning error"			"|de|Positionierfehler"			},
			{11,	"SEDITAX/SIGMATAX error occured"	"|de|SEDITAX/SIGMATAX Fehler erkannt"	},
			{12,	"SEDITAX/SIGMATAX no sync"		"|de|SEDITAX/SIGMATAX nicht synchron"	},
			{13,	"SEDITAX/SIGMATAX offline"		"|de|SEDITAX/SIGMATAX nicht aktiv"	},
			{14,	"no sample"				"|de|keine Probe"			},
			{15,	"fault signal"				"|de|Fehlerhaftes Signal"		},
			{16,	"fault offset"				"|de|Fehlerhafter Offset"		},
			{17,	"temperature sensor"			"|de|Temperatur Sensor"			},
			{18,	"gain"					"|de|Verstrkung"			},
			{19,	"calibration"				"|de|Kalibrierung"			}
			
			
	}
	HANDLING	READ;
}

VARIABLE Correction
{
	LABEL 	"Correction GP"	"|de|Korrekturwert GP";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
}

VARIABLE Correction_OR
{
	LABEL 	"Correction OR"	"|de|Korrekturwert OR";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
}

VARIABLE Ratio
{
	LABEL 	"Ratio OP/GP"	"|de|Verhltnis OP/GP";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
		{
			{ 1,			"0 : 1"	}
			{16,			"1 : 0"	}			
			{17,			"1 : 1"	}
			{18,			"1 : 2"	}
			{19,			"1 : 3"	}
			{20,			"1 : 4"	}
			{21,			"1 : 5"	}
			{22,			"1 : 6"	}
			{23,			"1 : 7"	}
			{24,			"1 : 8"	}
			{25,			"1 : 9"	}
			{26,			"1 : 10"}
			{32,			"2 : 0" }
			{33,			"2 : 1" }
			{34,			"2 : 2" }
			{35,			"2 : 3" }
			{36,			"2 : 4" }
			{37,			"2 : 5" }
			{38,			"2 : 6" }
			{39,			"2 : 7" }
			{40,			"2 : 8" }
			{41,			"2 : 9" }
			{42,			"2 : 10"}
			{48,			"3 : 0"	}
			{49,			"3 : 1"	}
			{50,			"3 : 2"	}
			{51,			"3 : 3"	}
			{52,			"3 : 4"	}
			{53,			"3 : 5"	}
			{54,			"3 : 6"	}
			{55,			"3 : 7"	}
			{56,			"3 : 8"	}
			{57,			"3 : 9"	}
			{58,			"3 : 10"}
			{64,			"4 : 0"	}
			{65,			"4 : 1"	}
			{66,			"4 : 2"	}
			{67,			"4 : 3"	}
			{68,			"4 : 4"	}
			{69,			"4 : 5"	}
			{70,			"4 : 6"	}
			{71,			"4 : 7"	}
			{72,			"4 : 8"	}
			{73,			"4 : 9"	}
			{74,			"4 : 10"}
			{80,			"5 : 0"	}
			{81,			"5 : 1"	}
			{82,			"5 : 2"	}
			{83,			"5 : 3"	}
			{84,			"5 : 4"	}
			{85,			"5 : 5"	}
			{86,			"5 : 6"	}
			{87,			"5 : 7"	}
			{88,			"5 : 8"	}
			{89,			"5 : 9"	}
			{90,			"5 : 10"}
						
						
	
		            	
		}
	HANDLING	READ & WRITE ;
}



VARIABLE Offset
{
	LABEL 	"Offset"	"|de|Offset";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
}

VARIABLE Channel_1
{
	LABEL 	"Channel 1"	"|de|Kanal 1";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}

VARIABLE Channel_2
{
	LABEL 	"Channel 2"	"|de|Kanal 2";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
}

VARIABLE Integration
{
	LABEL 	"Integration"	"|de|Mittelwertbildung";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{

		{1,	"OFF"			"|de|AUS"		},
		{2,	"2 measurements"	"|de|2 Messungen"	},
		{3,	"3 measurements"	"|de|3 Messungen"	},
		{4,	"4 measurements"	"|de|4 Messungen"	},
		{5,	"5 measurements"	"|de|5 Messungen"	},
		{6,	"6 measurements"	"|de|6 Messungen"	},
		{7,	"7 measurements"	"|de|7 Messungen"	},
		{8,	"8 measurements"	"|de|8 Messungen"	},
		{9,	"9 measurements"	"|de|9 Messungen"	},
		{10,	"10 measurements"	"|de|10 Messungen"	},
		{11,	"11 measurements"	"|de|11 Messungen"	},
		{12,	"12 measurements"	"|de|12 Messungen"	},
		{13,	"13 measurements"	"|de|13 Messungen"	},
		{14,	"14 measurements"	"|de|14 Messungen"	},
		{15,	"15 measurements"	"|de|15 Messungen"	},
		{16,	"16 measurements"	"|de|16 Messungen"	},
		{17,	"17 measurements"	"|de|17 Messungen"	},
		{18,	"18 measurements"	"|de|18 Messungen"	},
		{19,	"19 measurements"	"|de|19 Messungen"	},
		{20,	"20 measurements"	"|de|20 Messungen"	}
		
		
	        }
	HANDLING	READ & WRITE;
}

VARIABLE Calib_standard
{
	LABEL 	"Calibration Standard"	"|de|Kalibrierstandard"	;
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE Meas_Interval
{
	LABEL 	"Measuring Interval"	"|de|Messinterval"	;
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"5 Minutes"		"|de|5 Minuten"		},
		{1,	"10 Minutes"		"|de|10 Minuten"	}
		
        }
	HANDLING	READ & WRITE;
}





VARIABLE CleaningInterval
{
	LABEL 	"Cleaning interval"	"|de|Reinigungsinterval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"Cleaning OFF"		"|de|AUS"		},
		{24,	"1 Day"			"|de|1 Tag"		},
		{48,	"2 Days"		"|de|2 Tage"		},
		{72,	"3 Days"		"|de|3 Tage"		},
		{96,	"4 Days"		"|de|4 Tage"		},
		{120,	"5 Days"		"|de|5 Tage"		},
		{144,	"6 Days"		"|de|6 Tage"		},
		{168,	"1 Week"		"|de|1 Woche"		}
		
        }
	HANDLING	READ & WRITE;
}

VARIABLE CalibrationInterval
{
	LABEL 	"Calibration Interval"	"|de|Kalibrierinterval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"Cleaning OFF"		"|de|AUS"		},
		{24,	"1 Day"			"|de|1 Tage"		},
		{48,	"2 Days"		"|de|2 Tage"		},
		{72,	"3 Days"		"|de|3 Tage"		},
		{96,	"4 Days"		"|de|4 Tage"		},
		{120,	"5 Days"		"|de|5 Tage"		},
		{144,	"6 Days"		"|de|6 Tage"		},
		{168,	"1 Week"		"|de|1 Woche"		}
		
        }
	HANDLING	READ & WRITE;
}

VARIABLE Process
{
	LABEL 	"Process Phase"		"|de|Prozess Schritt";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	"Wait"				"|de|Pause"		},
		{1,	"Measuring"			"|de|Messen"		},
		{2,	"base"				"|de|Grundzustand"	},
		{3,	"Calibration"			"|de|Kalibrierung"	},
		{4,	"Cleaning"			"|de|Reinigung"		},
		{5,	"Priming"			"|de|Vorbereiten"	},
		{6,	"Measuring OP"			"|de|Messen OP"		},
		{7,	"Flushing"			"|de|Splen"		}
		
        }
	HANDLING	READ;
}

VARIABLE Clean
{
	LABEL 	"Start Cleaning "		      "|de|Anforderung Reinigen";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
	{
		{0,	"No request"	              "|de|Keine Anforderung"	},
		{1,	"request cleaning cycle"      "|de|Start Reinigung"	}
        }
	HANDLING	READ & WRITE;
}

VARIABLE Calibrate
{
	LABEL 	"Start Calibration"		      "|de|Anforderung Kalibrieren";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
	{
		{0,	"No request"		      "|de|Keine Anforderung"	},
		{1,	"request calibration cycle"   "|de|Start Kalibrierung"	}
        }
	HANDLING	READ & WRITE;
}

VARIABLE Mes
{
	LABEL 	"MES "			"|de|MES Kanal Rohwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE E_meas
{
	LABEL 	"Extinction to measured value" "|de|Ext.des aktuellen Messwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE Ref
{
	LABEL 	"REF"			"|de|REF Kanal Rohwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE Mes_N
{
	LABEL 	"MES null calibration"	"|de|MES Nullpunkt Kalibrierwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE Ref_N
{
	LABEL 	"REF null calibration"	"|de|REF Nullpunkt Kalibrierwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE Cal_factor
{
	LABEL 	"Calibration factor"	"|de|Kalibrierfaktor";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
}

VARIABLE Temp
{
	LABEL 	"Temperature"		"|de|Temperatur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
	
        }
	HANDLING	READ;
	DISPLAY_FORMAT ".2f";
	CONSTANT_UNIT "C";
}

VARIABLE Wiperstatus
{
	LABEL 	"Wiper status"		"|de|Status Wischer";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
	{
		{0,	"wiper park position" 	"|de|Wischer Stop"  },
		{1,	"run wiper cycle."	"|de|Wischer Start" }
        }
	HANDLING	READ & WRITE;
}

VARIABLE Wiperprofile
{
	LABEL 	"Wiper replace counter"	"|de|Wischer Zykluszhler";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
        {
	
        }
	HANDLING	READ;
}

VARIABLE Motorcycles
{
	LABEL 	"Motor counter"		"|de|Motor Zykluszhler";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
	        {
		
	        }
	HANDLING	READ;

}

VARIABLE SampleLocation
{
	LABEL 	"Probe Location"	"|de|Name Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (10)
		{
			DEFAULT_VALUE " ";
		}
	HANDLING	READ & WRITE;
}

VARIABLE ObererGrenzwert
{
	LABEL 	"Hi Limit"		"|de|Oberer Grenzwert";
	CLASS	CONTAINED & OUTPUT;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  100.0;
			
        }
	HANDLING	READ;
}

VARIABLE UntererGrenzwert
{
	LABEL 	"Lo Limit"		"|de|Unterer Grenzwert";
	CLASS	CONTAINED & OUTPUT;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  -1.0;
			
        }
	HANDLING	READ;
}

VARIABLE VendorName
{
	LABEL 	"Vendor name"		"|de|Hersteller";
	CLASS	CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "Hach-Lange";
		}
	HANDLING	READ;
}

VARIABLE ModelName
{
	LABEL 	"Device typ"		"|de|Geraetetyp";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE " ? ";
		}
	HANDLING	READ;
}

VARIABLE ModelNummer
{
	LABEL 	"Model number"		"|de|Modelnummer";
	CLASS	CONTAINED;
	TYPE	ASCII (32)
		{
			DEFAULT_VALUE "123456789";
		}
	HANDLING	READ;
}

VARIABLE func1_AI_out_upper_range_value
{
	LABEL 		[func_upper_value];
	HELP		[func_out_scale_upper_value_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE 140.0;
	}
	HANDLING	READ;
}

VARIABLE func1_AI_out_lower_range_value
{
	LABEL 		[func_lower_value];
	HELP		[func_out_scale_lower_value_help];
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE -50.0;
	}
	HANDLING	READ & WRITE;
}
/*
VARIABLE func1_AI_out_unit_m
{
	LABEL 		"Masseinheit";
	HELP		[digital_units_help];
	CLASS		CONTAINED;
	TYPE	ASCII (16)
		{
			DEFAULT_VALUE "  ";
		}
	HANDLING	READ;

}
*/
VARIABLE func1_AI_out_decimal_point
{
	LABEL		[decimal_point];
	HELP		[decimal_point_help];
	CLASS		CONTAINED;
	TYPE		INTEGER (1)
	{
		DEFAULT_VALUE	2;
		{	0,   "0"		},
		{	1,   "1"		},
		{	2,   "2"		},
		{	3,   "3"		},
		{	4,   "4"		},
		{	5,   "5"		},
		{	6,   "6"		},
		{	7,   "7"		}
	}
	HANDLING	READ;
}

UNIT Select_unit
{
	Unit:
	Measurement,
	Measurement_OR
//	ObererGrenzwert,
//	UntererGrenzwert
//	func1_AI_hi_hi_lim,
//	func1_AI_lo_lo_lim
}

VARIABLE func1_AI_hi_hi_lim
{
	LABEL		"ObererGrenzwert";
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	100.0 ;
		MIN_VALUE		-50.0 ;
		MAX_VALUE		750.0 ;
	}
	HANDLING	READ;
}

VARIABLE func1_AI_lo_lo_lim
{
	LABEL		"UntererGrenzwert";
	CLASS		CONTAINED;
	TYPE        FLOAT
	{
		DEFAULT_VALUE	  0.0 ;
		MIN_VALUE		-50.0 ;
		MAX_VALUE		750.0 ;
	}
	HANDLING	READ;
}

/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/




COMMAND read_VendorName
{
	SLOT 0;
	INDEX 100;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            VendorName
        }
    }
}

COMMAND read_ModelName
{
	SLOT 0;
	INDEX 101;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelName
        }
    }
}

COMMAND read_ModelNummer
{
	SLOT 0;
	INDEX 102;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            ModelNummer
        }
    }
}

COMMAND read_Measurement
{
	SLOT 1;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Measurement
        }
    }
}

COMMAND read_Measurement_OR
{
	SLOT 1;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Measurement_OR
        }
    }
}

COMMAND read_Unit
{
	SLOT 1;
	INDEX 7;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Unit
        }
    }
}



COMMAND read_Parameter
{
	SLOT 1;
	INDEX 8;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Parameter
        }
    }
}

COMMAND read_Parameter_OR
{
	SLOT 1;
	INDEX 9;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Parameter_OR
        }
    }
}

COMMAND read_ErrorClasses
{
	SLOT 1;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         0,
         0,
         ErrorClasses
        }
    }
}


COMMAND read_Status
{
	SLOT 1;
	INDEX 1;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Status
        }
    }
}

COMMAND read_Error
{
	SLOT 1;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Error
        }
    }
}

COMMAND read_Correction
{
	SLOT 1;
	INDEX 12;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Correction
        }
    }
}

COMMAND write_Correction
{
	SLOT 1;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Correction
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_Correction_OR
{
	SLOT 1;
	INDEX 14;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            Correction_OR
        }
    }
}

COMMAND write_Correction_OR
{
	SLOT 1;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Correction_OR
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_Process
{
	SLOT 1;
	INDEX 58;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         0,
         0,
         Process
        }
    }
}


COMMAND read_Ratio
{
	SLOT 1;
	INDEX 16;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            Ratio
        }
    }
}

COMMAND write_Ratio
{
	SLOT 1;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Ratio
        }
        REPLY
        {
         
        }
    }
}


COMMAND read_CalibrationInterval
{
	SLOT 1;
	INDEX 34;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            CalibrationInterval
        }
    }
}

COMMAND write_CalibrationInterval
{
	SLOT 1;
	INDEX 34;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        CalibrationInterval
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_CleaningInterval
{
	SLOT 1;
	INDEX 28;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            CleaningInterval
        }
    }
}

COMMAND write_CleaningInterval
{
	SLOT 1;
	INDEX 28;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        CleaningInterval
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_Mes
{
	SLOT 1;
	INDEX 61;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         Mes 
        }
    }
}

COMMAND read_Ref
{
	SLOT 1;
	INDEX 63;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         Ref 
        }
    }
}

COMMAND read_Mes_N
{
	SLOT 1;
	INDEX 48;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         Mes_N 
        }
    }
}

COMMAND read_Ref_N
{
	SLOT 1;
	INDEX 50;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         Ref_N 
        }
    }
}

COMMAND read_Cal_factor
{
	SLOT 1;
	INDEX 52;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         Cal_factor
        }
    }
}

COMMAND read_E_meas
{
	SLOT 1;
	INDEX 59;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         E_meas
        }
    }
}

COMMAND read_Temp
{
	SLOT 1;
	INDEX 65;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        
        }
        REPLY
        {
         Temp
        }
    }
}


COMMAND read_SampleLocation
{
	SLOT 1;
	INDEX 21;
    	OPERATION READ;
    	TRANSACTION
    	{
        REQUEST
        {
        }
        REPLY
        {
            SampleLocation
        }
    }
}

COMMAND write_SampleLocation
{
	SLOT 1;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        SampleLocation
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_Clean
{
	SLOT 1;
	INDEX 42;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
         0,
         0,
         Clean
        }
    }
}

COMMAND write_Clean
{
	SLOT 1;
	INDEX 42;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Clean
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_Calibrate
{
	SLOT 1;
	INDEX 41;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
         0,
         0,
         Calibrate
        }
    }
}

COMMAND write_Calibrate
{
	SLOT 1;
	INDEX 41;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        Calibrate
        }
        REPLY
        {
            
        }
    }
}

/************************************************************************/
/*  Daten lesen vom Gert zum PC  Read from Device To PC		*/
/************************************************************************/

MENU download_variables
{
	LABEL	[menu_load_to_PC];
	ITEMS
	{ 
		VendorName,
		ModelName,
		ModelNummer,
		Measurement,
		Measurement_OR,
		Unit,
		Parameter,
		Parameter_OR,
		Status,
		Error,
		ErrorClasses,
		Correction,
		Correction_OR,
		Process,
		Ratio,
		CalibrationInterval,
		CleaningInterval,
		Mes,
		Ref,
		Mes_N,
		Ref_N,
		SampleLocation,
		Cal_factor,
		E_meas,
		Temp
				
	}
} 


/************************************************************************/
/*  Datenschreiben vom PC zum Gert   Write From PC To Device	        */
/************************************************************************/

MENU upload_variables
{
	LABEL	[menu_load_to_device];
	ITEMS
	{
		Ratio,
		Correction,
		Correction_OR,
		SampleLocation,
		CleaningInterval,
		CalibrationInterval
		
	}
}

/************************************************************************/
/*	  Table: Specialist													*/
/************************************************************************/

MENU Table_Main_Specialist
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_s_preferences,
		Tab_s_settings,
		Tab_s_diag,
		Tab_s_output
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Specialist
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_S_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_S_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC,
        SEPARATOR,
	OnlineWindow_range_preferences,
	OnlineWindow_clean_calib
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_S_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
        OnlineWindow_yt
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU OnlineWindow_range_preferences
{
    LABEL	"Change settings"  	"|de|Wechseln der Voreinstellungen";
    ITEMS
    {
		Page_range_preferences 
    }
}

MENU Page_range_preferences
{
    LABEL	"Settings"	"|de|Voreinstellungen";
    ITEMS
    	{
	SampleLocation,
	Ratio,
	CleaningInterval,
	CalibrationInterval,
	Correction,
	Correction_OR
	}
}

MENU OnlineWindow_clean_calib
{
    LABEL	"Service"  	"|de|Reinigen/Kalibrieren";
    ITEMS
    {
		Page_clean_calib 
    }
}

MENU Page_clean_calib
{
    LABEL	"Service"	"|de|Funktionen";
    ITEMS
    	{
	Clean,
	Calibrate,
	Process
	}
}

MENU Tab_s_preferences
{
    LABEL	"Overview"		"|de|Geraetedaten";
    ITEMS
    {
		VendorName,
		ModelName,
		ModelNummer,
		SampleLocation


    }
}

MENU Tab_s_output
{
	LABEL	"Measured Value"	"|de|Messwerte";
	ITEMS
	{
		Measurement,
		Measurement_OR,
		Temp

	}
}

MENU Tab_s_diag
{
	LABEL	"Diagnostics"		"|de|Diagnosedaten";
	ITEMS
	{
		ErrorClasses,
		Status,
		Parameter,
		Parameter_OR,
		Error,
		Process,
		Mes,
		Ref,
		Mes_N,
		Ref_N,
		Cal_factor,
		E_Meas
	}
}

MENU Tab_s_settings
{
	LABEL		"Settings"	"|de|Einstellungen";
	ITEMS
	{
		Unit,
		Correction,
		Correction_OR,
		Ratio,
		CleaningInterval,
		CalibrationInterval,
		Parameter,
		Parameter_OR
		
	}
}


/************************************************************************/
/*	  Table: Maintenance												*/
/************************************************************************/

MENU Table_Main_Maintenance
{
	LABEL	DEVICE_TITLE ;

	ITEMS
	{
		Tab_m_preferences,
		Tab_m_output,
		Tab_m_settings,
		Tab_m_diag
	}
}

/************************************************************************/
/*	  Main Menus														*/
/************************************************************************/

/************************************************************************/
/*	  Menu: Bar															*/
/************************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL		[main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_M_View,
        //Menu_M_Options,
        Menu_Help
    }
}

/************************************************************************/
/*	  Menu: Device														*/
/************************************************************************/

MENU Menu_M_Device
{
    LABEL		[menu_Device];
    ITEMS
    {
        std_LoadinDevice,
        std_LoadinPC
    }
}

/************************************************************************/
/*	  Menu: View														*/
/************************************************************************/

MENU Menu_M_View
{
    LABEL		[menu_View];
    ITEMS
    {
        OnlineWindow_display,
        OnlineWindow_yt
//	OnlineWindow_actual_mode
    }
}

/************************************************************************/
/*	  Online-Windows													*/
/************************************************************************/

MENU Tab_m_preferences
{
    	LABEL	"Overview"		"|de|Geraetedaten";
        ITEMS
        {
    		VendorName,
    		ModelName,
    		ModelNummer,
    		SampleLocation
    
    
    }
}

MENU Tab_m_output
{
	LABEL	"Measured Value"	"|de|Messwert";
	ITEMS
	{
		Measurement,
		Measurement_OR,
		Temp

	}
}

MENU Tab_m_diag
{
	LABEL	"Diagnostics"		"|de|Diagnosedaten";
	ITEMS
	{
		ErrorClasses,
		Status,
		Parameter,
		Parameter_OR,
		Error,
		Process,
		Mes,
		Ref,
		Cal_factor,
		E_Meas
	}
}


MENU Tab_m_settings
{
	LABEL		"Settings"	"|de|Einstellungen";
	ITEMS
	{
		Unit			(READ_ONLY),
		Correction		(READ_ONLY),
		Correction_OR		(READ_ONLY),
		Ratio			(READ_ONLY),
		CleaningInterval	(READ_ONLY),
		CalibrationInterval	(READ_ONLY),
		Parameter		(READ_ONLY),
		Parameter_OR		(READ_ONLY)
}		
	}
MENU OnlineWindow_actual_mode
{
	LABEL			"Aktueller Modus";
	ITEMS
	{
		Parameter	(READ_ONLY)
		Parameter_OR	(READ_ONLY)


	}
}

MENU OnlineWindow_display
{
	LABEL		[menu_dialog_display];
	ITEMS
	{
		Page_display_func1
	}
}

MENU Page_display_func1
{
	LABEL     "Measured Value" 	"|de|Messwerte";
	ITEMS
	{
		BarVal_out_display_func1,
		BarVal_out_display_func2,
		BarVal_out_display_func3,
		BarVal_out_display_func4
				
	}
}


MENU BarVal_out_display_func1
{
	LABEL		"Current Value" 	"|de|aktuell GP";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		Measurement				(READ_ONLY),
		func1_AI_out_lower_range_value		(READ_ONLY),
		func1_AI_out_upper_range_value		(READ_ONLY)		
	}
}

MENU BarVal_out_display_func2
{
	LABEL		"Current Value" 	"|de|aktuell OR";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		Measurement_OR				(READ_ONLY),
		func1_AI_out_lower_range_value		(READ_ONLY),
		func1_AI_out_upper_range_value		(READ_ONLY)		
	}
}

MENU BarVal_out_display_func3
{
	LABEL		"Current Temperature Value" 	"|de|Temperatur Cels";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		Temp				(READ_ONLY),
		func1_AI_out_lower_range_value		(READ_ONLY),
		func1_AI_out_upper_range_value		(READ_ONLY)		
	}
}

MENU BarVal_out_display_func4
{
	LABEL		"Current Step" 	"|de|Prozessschritt";
	HELP		[func_ai_out_value_help];
	ITEMS
	{
		Process				(READ_ONLY)
			
	}
}