/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2005). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC1000 V1       		   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			25.Nov 2005			   */
/*	File:			S2_Solitax.inc			   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/


/************************************************************************/
/*		Variables						*/
/************************************************************************/



VARIABLE S2_Measurement1
{
	LABEL 	"Measurement Value" 	"|de|Messwert FNU";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"FNU";
}

VARIABLE S2_Measurement2
{
	LABEL 	"Measurement Value" 	"|de|Messwert EBC";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"EBC";
}

VARIABLE S2_Measurement3
{
	LABEL 	"Measurement Value" 	"|de|Messwert mg/l";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"mg/l";
}

VARIABLE S2_Measurement4
{
	LABEL 	"Measurement Value" 	"|de|Messwert g/l";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"g/l";
}

VARIABLE S2_Measurement5
{
	LABEL 	"Measurement Value" 	"|de|Messwert %";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"%";
}

VARIABLE S2_UnitTRB
{
	LABEL 	"Unit turbidity" 			"|de|Einheit Trbung";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
		{
		
			{6,			"FNU"	},
			{7,			"NTU"   },
			{9,			"EBC"   }
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}


VARIABLE S2_UnitTS
{
	LABEL 	"Unit suspendet solids"			"|de|Einheit Feststoff";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
		{
			DEFAULT_VALUE 0;
			{0,			"mg/l"	},
			{1,			"g/l"   }
									
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

VARIABLE S2_Parameter
{
	LABEL 	"Measurement Mode" 	"|de|Betriebsart";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			{0,			"Turbidity" 		"|de|Trbung" 	},
			{1,			"Suspendet solids" 	"|de|Feststoff"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_CorrectionTRB
{
	LABEL 	"Correction TRB""|de|Korrekturfaktor TRB";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_CorrectionTS
{
	LABEL 	"Correction TS""|de|Korrekturfaktor TS";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  1.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_OffsetTRB
{
	LABEL 	"Offset TRB""|de|Offset TRB";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			DEFAULT_VALUE  0.0;
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_Integration
{
	LABEL 	"Integration"	"|de|Integration in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_CleaningInterval
{
	LABEL 	"Cleaning interval" "|de|Reinigungsinterval";
	CLASS	CONTAINED;
	TYPE	ENUMERATED (2)
	{
		{0,	""					},
		{1,	"1 Min."				},
		{5,	"5 Min"					},
		{15,	"15 Min"				},
		{30,	"30 Min"				},
		{60,	"1 houre"	"|de|1 Stunde"		},
		{240,	"4 houres"	"|de|4 Stunden"		},
		{720,	"12 houres"	"|de|12 Stunden"	},
		{1440,	"24 houres"	"|de|24 Stunden"	},
		{4320,	"3  days"	"|de|3 Tage"		},
		{1080,	"7  days"	"|de|7 Tage"		}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_Wiperstatus
{
	LABEL 	"Wiper status" "|de|Wischerstatus";
	CLASS	CONTAINED;
	TYPE	UNSIGNED_INTEGER (2)
	{
		{0,	"wiper park position"	"|de|Wischer Stop"},
		{1,	"run wiper cycle."	"|de|Wischer Start"}
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
	
}

VARIABLE S2_Wiperprofile
{
	LABEL 	"Wiper replace counter" "|de|Wischblatt Zykluszhler";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE S2_Motorcycles
{
	LABEL 	"Motor counter" "|de|Motor Zykluszhler";
	CLASS	CONTAINED;
	TYPE	INTEGER (4)
	        {
		
	        }
	HANDLING	READ;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;

}

VARIABLE S2_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (15)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}


/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/


COMMAND read_S2_Measurement1
{
	SLOT 22;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            S2_Measurement1
        }
    }
}

COMMAND read_S2_Measurement2
{
	SLOT 22;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            S2_Measurement2
        }
    }
}

COMMAND read_S2_Measurement3
{
	SLOT 22;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            S2_Measurement3
        }
    }
}

COMMAND read_S2_Measurement4
{
	SLOT 22;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            S2_Measurement4
        }
    }
}

COMMAND read_S2_Measurement5
{
	SLOT 22;
	INDEX 8;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            S2_Measurement5
        }
    }
}

COMMAND read_S2_UnitTRB
{
	SLOT 22;
	INDEX 12;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_UnitTRB
        }
    }
}

COMMAND write_S2_UnitTRB
{
	SLOT 22;
	INDEX 12;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_UnitTRB
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_UnitTS
{
	SLOT 22;
	INDEX 13;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_UnitTS
        }
    }
}

COMMAND write_S2_UnitTS
{
	SLOT 22;
	INDEX 13;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_UnitTS
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_S2_OffsetTRB
{
	SLOT 22;
	INDEX 14;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            S2_OffsetTRB
        }
    }
}

COMMAND write_S2_OffsetTRB
{
	SLOT 22;
	INDEX 14;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_OffsetTRB
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_CorrectionTRB
{
	SLOT 22;
	INDEX 16;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            S2_CorrectionTRB
        }
    }
}

COMMAND write_S2_CorrectionTRB
{
	SLOT 22;
	INDEX 16;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_CorrectionTRB
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_CorrectionTS
{
	SLOT 22;
	INDEX 18;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            S2_CorrectionTS
        }
    }
}

COMMAND write_S2_CorrectionTS
{
	SLOT 22;
	INDEX 18;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_CorrectionTS
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_Integration
{
	SLOT 22;
	INDEX 21;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_Integration
        }
    }
}

COMMAND write_S2_Integration
{
	SLOT 22;
	INDEX 21;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_Integration
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_CleaningInterval
{
	SLOT 22;
	INDEX 22;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_CleaningInterval
        }
    }
}

COMMAND write_S2_CleaningInterval
{
	SLOT 22;
	INDEX 22;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_CleaningInterval
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_Wiperstatus
{
	SLOT 22;
	INDEX 20;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_Wiperstatus
        }
    }
}

COMMAND write_S2_Wiperstatus
{
	SLOT 22;
	INDEX 20;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_Wiperstatus
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_S2_Wiperprofile
{
	SLOT 22;
	INDEX 34;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_Wiperprofile
        }
    }
}

COMMAND write_S2_Wiperprofile
{
	SLOT 22;
	INDEX 34;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_Wiperprofile
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_S2_Parameter
{
	SLOT 22;
	INDEX 11;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            S2_Parameter
        }
    }
}

COMMAND write_S2_Parameter
{
	SLOT 22;
	INDEX 11;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
        S2_Parameter
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_S2_SampleLocation
{
	SLOT 22;
	INDEX 26;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            S2_SampleLocation
        }
    }
}

COMMAND write_S2_SampleLocation
{
	SLOT 22;
	INDEX 26;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              S2_SampleLocation
        }
        REPLY
        {
            
        }
    }
}

