/*-----------------------------------------------------------------*/
/*	Copyright (C)	Hach-Lange (2005). All Rights Reserved.	   */
/*	Product:		SIMATIC PDM  			   */
/*	Device:			SC1000 V1       		   */
/*	Description:		Device Description	           */
/*	Dictionary:		SIPADC01.dct			   */
/*  	$Revision:		0.1  $				   */
/*  	$Date:			10.Nov 2005			   */
/*	File:			L2_LDO.inc			   */
/*	Author:			T.Thiel Hach-Lange	           */
/*-----------------------------------------------------------------*/


/************************************************************************/
/*		Variables						*/
/************************************************************************/



VARIABLE L2_Measurement1
{
	LABEL 	"Oxygen Value" 	"|de|Messwert O2";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	
}

VARIABLE L2_Measurement2
{
	LABEL 	"Percent Saturation" 	"|de|Prozentuale Sttigung";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"%";
}

VARIABLE L2_Measurement3
{
	LABEL 	"Temperature Value" 	"|de|Temperatur";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"C ";
}

VARIABLE L2_Diag1
{
	LABEL 	"Total Phase Shift" 	"|de|Phasenverschiebung gesamt";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Grad";
}

VARIABLE L2_Diag2
{
	LABEL 	"Blue Phase Shift" 	"|de|Phasenverschiebung blau";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Grad";
}

VARIABLE L2_Diag3
{
	LABEL 	"Red Phase Shift" 	"|de|Phasenverschiebung rot";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"Grad";
}

VARIABLE L2_Diag4
{
	LABEL 	"Blue Amplitude" 	"|de|Amplitude blau";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"0..1";
}

VARIABLE L2_Diag5
{
	LABEL 	"Red Amplitude" 	"|de|Amplitude rot";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
	CONSTANT_UNIT 	"0..1";
}


VARIABLE L2_Diag6
{
	LABEL 	"Software version" 	"|de|Softwareversion";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
			
        }
	HANDLING	READ;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
	DISPLAY_FORMAT 	".2f";
}

VARIABLE L2_AltPress
{
	LABEL 	"Altitude/Pressure"	"|de|Hhe/Druck";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		5000 ;		
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE L2_Salinity
{
	LABEL 	"Salinity"		"|de|Salzgehalt";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.0 ;
		MAX_VALUE		5000 ;		
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE L2_UnitConc
{
	LABEL 	"Concentration Unit" 			"|de|Einheit O2 Konzentration";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
		{
			DEFAULT_VALUE 0;
			{0,			"mg/l"	},
			{2,			"ppm"	},
			{10,			"%"     }
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

UNIT Select_unit		// dynymic unit relation
{
	L2_UnitConc:
	L2_Measurement1,

}

VARIABLE L2_UnitTemp
{
	LABEL 	"Temperature Unit"			"|de|Einheit Temperatur";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
		{
			DEFAULT_VALUE 25;
			
			{25,			"C"   	},
			{26,			"F"     }
			
						
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 	4000;
	WRITE_TIMEOUT 	4000;
}

UNIT Select_unit_T		// dynymic unit relation
{
	L2_UnitTemp:
	L2_Measurement3,

}

VARIABLE L2_UnitAltP
{
	LABEL 	"Alt Pressure Unit" 	"|de|Einheit Hhe/Druck";
	CLASS	DYNAMIC;
	TYPE	INTEGER (2)
		{
			{13,		"m" 		"|de|Meter" 	},
			{43,		"feet" 	        "|de|Fu"	},
			{45,		"mmHg" 		"|de|mmHg" 	},
			{47,		"torr" 		"|de|torr"	}
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE L2_CorrectionSlope
{
	LABEL 	"Correction Slpope"	"|de|Korrekturfaktor Steilheit";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		0.5 ;
		MAX_VALUE		1.5 ;		
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE L2_Correction
{
	LABEL 	"Calib Value"		"|de|Kalibrierwert";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		 0.0 ;
		MAX_VALUE		 20.0 ;	
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE L2_Offset
{
	LABEL 	"Offset "		"|de|Offset";
	CLASS	CONTAINED;
	TYPE	FLOAT
        {
		MIN_VALUE		-5.0 ;
		MAX_VALUE		 5.0 ;		
			
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}

VARIABLE L2_Integration
{
	LABEL 	"Integration"	"|de|Integration in Sekunden";
	CLASS	CONTAINED;
	TYPE	INTEGER (2)
        {
	
        }
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}


VARIABLE L2_SampleLocation
{
	LABEL 	"Probe Location" "|de|Einbauort";
	CLASS	CONTAINED;
	TYPE	ASCII (12)
		{
			DEFAULT_VALUE "";
		}
	HANDLING	READ & WRITE;
	READ_TIMEOUT 4000;
	WRITE_TIMEOUT 4000;
}


/************************************************************************/
/*		COMMANDS														*/
/************************************************************************/


COMMAND read_L2_Measurement1
{
	SLOT 22;
	INDEX 0;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Measurement1
        }
    }
}

COMMAND read_L2_Measurement2
{
	SLOT 22;
	INDEX 2;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Measurement2
        }
    }
}

COMMAND read_L2_Measurement3
{
	SLOT 22;
	INDEX 4;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Measurement3
        }
    }
}

COMMAND read_L2_Diag1
{
	SLOT 22;
	INDEX 6;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Diag1
        }
    }
}

COMMAND read_L2_Diag2
{
	SLOT 22;
	INDEX 8;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Diag2
        }
    }
}

COMMAND read_L2_Diag3
{
	SLOT 22;
	INDEX 12;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Diag3
        }
    }
}

COMMAND read_L2_Diag4
{
	SLOT 22;
	INDEX 12;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Diag4
        }
    }
}

COMMAND read_L2_Diag5
{
	SLOT 22;
	INDEX 14;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Diag5
        }
    }
}

COMMAND read_L2_Diag6
{
	SLOT 22;
	INDEX 16;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            L2_Diag6
        }
    }
}

COMMAND read_L2_AltPress
{
	SLOT 22;
	INDEX 40;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            L2_AltPress
        }
    }
}

COMMAND write_L2_AltPress
{
	SLOT 22;
	INDEX 40;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_AltPress
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_Salinity
{
	SLOT 22;
	INDEX 42;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            L2_Salinity
        }
    }
}

COMMAND write_L2_Salinity
{
	SLOT 22;
	INDEX 42;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_Salinity
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_Correction
{
	SLOT 22;
	INDEX 36;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            L2_Correction
        }
    }
}

COMMAND write_L2_Correction
{
	SLOT 22;
	INDEX 36;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_Correction
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_CorrectionSlope
{
	SLOT 22;
	INDEX 46;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            L2_CorrectionSlope
        }
    }
}

COMMAND write_L2_CorrectionSlope
{
	SLOT 22;
	INDEX 46;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_CorrectionSlope
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_Offset
{
	SLOT 22;
	INDEX 44;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            L2_Offset
        }
    }
}

COMMAND write_L2_Offset
{
	SLOT 22;
	INDEX 44;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_Offset
        }
        REPLY
        {
            
        }
    }
}


COMMAND read_L2_UnitConc
{
	SLOT 22;
	INDEX 90;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            L2_UnitConc
        }
    }
}

COMMAND write_L2_UnitConc
{
	SLOT 22;
	INDEX 90;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_UnitConc
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_UnitAltP
{
	SLOT 22;
	INDEX 91;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            L2_UnitAltP
        }
    }
}

COMMAND write_L2_UnitAltP
{
	SLOT 22;
	INDEX 91;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_UnitAltP
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_UnitTemp
{
	SLOT 22;
	INDEX 92;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            L2_UnitTemp
        }
    }
}

COMMAND write_L2_UnitTemp
{
	SLOT 22;
	INDEX 92;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_UnitTemp
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_Integration
{
	SLOT 22;
	INDEX 104;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            0,
            0,
            L2_Integration
        }
    }
}

COMMAND write_L2_Integration
{
	SLOT 22;
	INDEX 104;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_Integration
        }
        REPLY
        {
            
        }
    }
}

COMMAND read_L2_SampleLocation
{
	SLOT 22;
	INDEX 98;
    	OPERATION READ;
    	TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            
            L2_SampleLocation
        }
    }
}

COMMAND write_L2_SampleLocation
{
	SLOT 22;
	INDEX 98;
    	OPERATION WRITE;
    	TRANSACTION
    {
        REQUEST
        {
              L2_SampleLocation
        }
        REPLY
        {
            
        }
    }
}

