// SIHA5_Cmd0.inc
// Description: HART Command 0 and associated VARIABLEs


#include "Manufacturer_List.h"



#define USER_INTERFACE LOCAL
#define LOCAL_INTERFACE LOCAL_DISPLAY

#define I_NO_COMMAND_SPECIFIC_ERRORS			 0
#define I_INVALID_SELECTION						 2
#define I_PARAMETER_TOO_LARGE					 3
#define	I_PARAMETER_TOO_SMALL					 4
#define I_TOO_FEW_DATA_BYTES					 5
#define I_TRANSMITTER_SPECIFIC_ERROR			 6
#define I_IN_WRITE_PROTECT_MODE					 7
#define I_ACCESS_RESTRICTED						16


VARIABLE response_code
{
  HELP [command_specific_response_code_help];
/*
  APPHELP "NOTE- HART Revisions < 5 had a different specification for this"
	  " variable."
	  " "
	  "The Following Applies to HART Revision >= 5"
	  " Command Specific Response Codes are encoded in bits #6 - #0 of the"
	  " first byte of the Response Codes. These codes are 7-bit unsigned"
	  " integers, have values ranging from 0 to 127, and are not bit-mapped."
	  " "
	  "The Command Specific Response Codes have symbolic meanings which"
	  " fall into the following basic types:"
	  " "
	  "Success- Command executed properly. All Data Bytes are"
	  "         included in the Slave response."
	  " "
	  "Warning- Command executed was completed with a deviation, and the"
	  "         is described in the Command Specific Response Code."
	  "         All Data Bytes are included in the Slave response."
	  " "
	  "    Warnings with singular definitions are assigned to Command"
	  "    Specific Response Codes: 24-27, 96-111."
	  "    NOTE- For HART Revision < 5 the following groupings were not"
	  "    maintained per these definitions."
	  " "
	  "    Warnings with multiple definitions are assigned to Command"
	  "    Specific Response Codes: 8, 14, 30, 31, 112-127."
	  "    NOTE- For HART Revision < 5 the following groupings were not"
	  "    maintained per these definitions."
	  " "
	  "Error- Command execution was not completed, as defined by the"
	  "       Command, and the Command Specific Response Code indicates the"
	  "       reason. Therefore the Host request caused no change to"
	  "       occur in the Slave."
	  "       No Data Bytes, other than the two Response Code"
	  "       Bytes, should be included in the Slave response."
	  " "
	  "These basic types are further broken down into specific"
	  " 'Response Code Types'. See the Device Description Language
	  " Specification for the definitions of these 'Response Code Types'."
	  " "
	  "    Errors with singular definitions are assigned to Command"
	  "    Specific  Response Codes: 0-7, 16-23, 32, 33-63, 64."
	  "    NOTE- For HART Revision < 5 the following groupings were not"
	  "    maintained per these definitions."
	  " "
	  "        Response Codes #32 and #64 may be returned in response to"
	  "        any command. Their definitions follow:"
	  " "
	  "            Response Code #32"
	  "                Busy- The Field Device is performing a function that"
	  "                cannot be interrupted by this command. The Command"
	  "                was not accepted."
	  " "
	  "            Response Code #64"
	  "                Command Not Implemented- The Command was not"
	  "                defined for this device. The Command was not"
	  "                accepted."
	  " "
	  "    Errors with multiple definitions are assigned to Command"
	  "    Specific Response Codes: 9-13, 15, 28, 29, 65-95."
	  "    NOTE- For HART Revision < 5 the following groupings were not"
	  "    maintained per these definitions."
	  " "
	  "NOTE- General definitions for Command Specific Response Codes"
	  "are located in the Document 'Appendix 1- Command Specific Response"
	  "Code Definitions'."
	  " "
	  "    NOTE- These assignments must be observed whenever new Command"
	  "    Specific Response Codes are defined and added to existing, or"
	  "    new, commands so that the Master can respond properly to the"
	  "    new code.";
	  " HART_VAR:Part of the Frame, RESP-CODE BYTE 1";
*/
  CLASS USER_INTERFACE & DIAGNOSTIC;
  TYPE ENUMERATED
    {
		{ 0,  [success] },
		{ 1,  [undefined] },
		{ 2,  [invalid_selection] },
		{ 3,  [passed_parameter_too_large] },
		{ 4,  [passed_parameter_too_small] },
		{ 5,  [too_few_data_bytes_recieved] },
		{ 6,  [xmtr_specific_command_error] },
		{ 7,  [in_write_protect_mode] },
		{ 8,  [xmtr_specific_command_error] },
		{ 9,  [xmtr_specific_command_error] },
		{ 10, [xmtr_specific_command_error] },
		{ 11, [xmtr_specific_command_error] },
		{ 12, [xmtr_specific_command_error] },
		{ 13, [xmtr_specific_command_error] },
		{ 14, [xmtr_specific_command_error] },
		{ 15, [xmtr_specific_command_error] },
		{ 16, [access_restricted] },
		{ 32, [busy] },
		{ 64, [command_not_implemented] }
	}
  HANDLING READ;  /*  ??? eingefgt, lt. Spez. READ/Write  */
}


VARIABLE communication_status	  /*  ??? eingefgt */
{
	CLASS	LOCAL;
	TYPE	BIT_ENUMERATED
    {
		{ 0x01, [communication_error]		},
		{ 0x02, [buffer_overflow]			},
		{ 0x08, [longitudinal_parity_error] },
		{ 0x10, [framing_error]				},
		{ 0x20, [overrun_error]				},
		{ 0x40, [vertical_parity_error]		},
	}
  HANDLING READ;
}

VARIABLE device_status
{
    LABEL	[device_status] ;
	HELP	[field_device_status_help];
/*
  APPHELP "This condition does not affect the actions of the Command in the"
	  " Master request. Therefore, does not affect the number of Data Bytes"
	  " in the Slave response."
	  " The Communications Error Summary is a higher priority diagnostic."
	  " Therefore, the Field Device Status should not be evaluated by the"
	  " Host if a Communications Error Summary bit is set."
	  " These specific bits can be given attributes called 'Cause Status"
	  " Classes'. See the Device Description Language Specification for the"
	  " definitions of these 'Cause Status Classes'."
	  " HART_VAR:Part of the Frame, RESP-CODE BYTE 2";
*/
  CLASS LOCAL & HART & DYNAMIC & DIAGNOSTIC;
  TYPE BIT_ENUMERATED
    {
	{ 0x01, [PV_out_of_limits],	       DV1 (AUTO & BAD) },
	{ 0x02, [Non_PV_out_of_limits],        DV2 (AUTO & BAD) },
	{ 0x04, [PV_analog_output_saturated],  AO1 (AUTO & BAD) },
	{ 0x08, [PV_analog_output_fixed],      AO1 (MANUAL & GOOD) },
	{ 0x10, [more_status_available],       MORE },
	{ 0x20, [cold_start],		       MISC },
	{ 0x40, [configuration_changed],       MISC & IGNORE_IN_HANDHELD },
	{ 0x80, [device_malfunction],	       MORE}
    }
	HANDLING READ ;
	STYLE "MULTILINE 32 9" ;
}

VARIABLE manufacturer_id
{
  HELP [manufacturer_id_code_help];
/*
  APPHELP "For HART Revision >= 5
	  "    The long address of the frame is composed of the three variables"
	  "    manufacturer_id, device_type, and the device_id. The Long"
	  "    address is composed of 38 bits. The most significant bit is"
	  "    closest to the Delimiter Byte. Thus the least significant"
	  "    bit is located closest to the Command Byte. The least"
	  "    significant 6 bits of the variable manufacturer_id are mapped"
	  "    into the 6 most significant 6 bits of the long address. Note"
	  "    that the 2 most significant bits of the variable manufacturer_id"
	  "    are thrown away. The variable manufacturer_id is mapped into the"
	  "    next 8 most significant bits of the long address, and the"
	  "    device_id is mapped into the next 24 most significant bits of"
	  "    the long address."
	  " "
	  "    The variable manufacturer_id, combined with the variable"
	  "    device_type, will uniquely identify a type of Field Device. The"
	  "    combination of these two variables will have only one unique"
	  "    Device Description, though there may be revisions of the Device"
	  "    Description."
	  " "
	  "    The variable manufacturer_id, combined with the variable"
	  "    device_type, combined with the variable transmitter_revision,"
	  "    will identify the exact revision of the Device Description for"
	  "    this type of Field Device."
	  " "
	  "    The variable manufacturer_id, combined with the variable"
	  "    device_type, combined with the variable device_id, will"
	  "    uniquely identify a Field Device, such that there is only one"
	  "    such Field Device in the world."
	  " "
	  " NOTE- For HART Revision >= 5, the decimal numeric 254 that precedes"
	  " the manufacturer_id variable in Command #0 (i.e. one byte closer to"
	  " the Delimiter Byte), is part of an expansion mechanism that existed"
	  " for HART" Revisions < 5."
	  " NOTE- Rosemount Inc. subsidiaries should use their enumeration and"
	  " not 'Rosemount Inc.'.
	  " HART_VAR:MFR ID";
*/
  LABEL [manufacturer_id];
  HANDLING READ;
  CLASS HART;
  TYPE ENUMERATED
    {
	  DEFAULT_VALUE 252 ;

		MANUFACTURER_LIST
    }
}

VARIABLE device_type
{
	LABEL		[device_type];
	HELP		[manufacturers_device_type_help];
	HANDLING	READ;
	CLASS		HART;
	TYPE		ENUMERATED (1)
	{
		SELECT( manufacturer_id )
		{ 
		CASE 10:  // BROOKS INSTRUMENT
			{1, "TRI20"},
			{2, "38XXVA"},
			{3, "99XX OVAL"},

		CASE 14:  // DELTA
			{1, "HT"},

		CASE 17:  // ENDRESS HAUSER
			{0x03,"Prosonic / FMU 860"},
			{0x04,"Prosonic / FMU 861"},
			{0x05,"Prosonic / FMU 862"},
			{0x06,"Micropilot I / FMR 13x"},
			{0x07,"Cerabar S / PMx x3x"},
			{0x08,"Multicap / FEC 12"},
			{0x09,"Deltabar S / xMD x3x"},
			{0x0A,"Prosonic T / FMU x3x"},
			{0x0B,"Deltapilot S / DB 5x"},
			{0x0C,"Micropilot II / FMR 23x"},
			{0x0D,"Levelflex / FMP 2xx"},
			{0x0E,"Cerabar M / PMx 4x"},
			{0x0F,"Micropilot M / FMR 2xx"},
			{0x10,"Micropilot S / FMR 53x"},
			{0x11,"Prosonic M / FMU 4x"},
			{0x12,"Levelflex M / FMP 40"},
			{0x32,"Promag / 33"},
			{0x33,"Prowirl / 70"},
			{0x34,"Promass / 63"},
			{0x35,"Promag / 39"},
			{0x36,"Promag / 35 S"},
			{0x37,"Prowirl / 77"},
			{0x39,"Promass / 60"},
			{0x40,"Prosonic Flow / DMU93"},
			{0x41,"Promag / 50"},
			{0x42,"Promag / 53"},
			{0x43,"Promag / 51"},
			{0x45,"Promag / 10"},
			{0x46,"Promag / 23"},
			{0x50,"Promass / 80"},
			{0x51,"Promass / 83"},
			{0x53,"Promass / 40"},
			{0x56,"Prowirl / 72"},
			{0x57,"Prowirl / 73"},
			{0x58,"Prosonic Flow / 90"},
			{0x59,"Prosonic Flow / 93"},
			{0x78,"Omnigrad / TMD 832"},
			{0x79,"Omnigrad / TMD 833"},
			{0x7C,"Omnigrad / TMD 842"},
			{0x8C,"Mypro PH / CPM 431"},
			{0x8D,"Mypro Cond. C / CLx 431"},
			{0x8E,"Mypro Cond. I / CLx 431"},
			{0x91,"Liquisys M PH / CPM 2x3"},
			{0x92,"Liquisys M Cond. I / CLM 2x3"},
			{0x93,"Liquisys M Cond. C / CLM 2x3"},
			{0x94,"Liquisys M DO / COM 2x3"},
			{0x95,"Liquisys M Turbidity / CUM 2x3"},
			{0x96,"Liquisys M Chlorine / CCM 2x3"},
			{0x97,"Smartec S / CLD 132"},
			{0xC8,"iTemp / TMT 182"},
			{0xC9,"iTemp / TMT 122"},
			{0xCA,"iTemp / TMT 162"},
			  {100, "AT70"},
			  {181, "NMT530"},
			  {255, "FIELDTEST"},

		CASE 18:  // BAILEY FISCHER AND PORTER
			{7, "50XM2000"},
			{8, "50XE4000"},
			{14, "50VT1000"},
			{15, "50VM1000"},
			{25, "50XM1000"},
			{26, "50SM1000"},
			{66, "PTH"},

		CASE 19:  // FISHER CONTROLS
			{1, "DT"},
			{2, "DVC"},

		CASE 20:  // FOXBORO
			{41, "IMT25"},
			{46, "IA PRESSURE"},
			{51, "ITVORTEX"},

		CASE 21:  // FUJI
			{1, "FCX"},

		CASE 22:  // HARTMANN BRAUN
			{3, "TEU471"},
			{4, "TEU421"},
			{5, "TEU211"},
			{6, "TS11"},
			{64, "TZID"},
			{65, "TZIDC"},
			{133, "AS800"},

		CASE 23:  // HONEYWELL
			{1, "ST3000"},
			{3, "HWFLOW"},
			{4, "STT250"},

		CASE 25:  // KAY RAY SENSALL
			{8, "4050"},
			{9, "3680"},
			{10, "4790"},
			{15, "3280"},

		CASE 26:  // ABB
			{1, "KSX"},
			{2, "PX"},
			{8, "KST"},
			{10, "658T"},
			{12, "653S"},
			{16, "VALVE"},
			{24, "FLOW"},
			{32, "LEVEL"},

		CASE 31:  // MICRO MOTION
			{7, "9712"},
			{20, "9720"},
			{21, "9739"},
			{30, "9701"},

		CASE 32:  // MOORE INDUSTRIES
			{1, "TRZ"},
			{3, "THZ"},

		CASE 33:  // MOORE PRODUCTS
			{1, "340 A"},
			{2, "340 B"},
			{3, "344"},
			{5, "341"},
			{6, "340 A2"},
			{8, "340 B2"},
			{9, "344 2"},
			{10, "340 S"},
			{11, "343"},
			{12, "760 D"},
			{13, "345"},

		CASE 38:  // ROSEMOUNT
			{1, "3051"},
			{2, "3044"},
			{3, "1151s"},
			{4, "8712"},
			{5, "2001"},
			{6, "3051C"},
			{11, "3001L"},
			{12, "8712H"},
			{13, "3044C"},
			{14, "3001C"},
			{15, "3051CLP"},
			{16, "8800"},
			{17, "3201"},
			{18, "1152"},
			{19, "3202"},
			{20, "3001S"},
			{22, "3095MV"},
			{24, "644"},
			{25, "3144"},
			{26, "3244"},
			{28, "APEX"},
			{29, "TRILOOP"},
			{30, "3095C"},
			{35, "2088"},
			{36, "PROBAR"},
			{39, "2090"},
			{40, "PROBAR UC"},
			{127, "HART COMMUNICATOR"},
			{128, "UNIVERSAL XMTR"},

		CASE 39:  // PEEK MEASUREMENT
			{0, "FD900"},

		CASE 40:  // SCHLUMBERGER
			{1, "NEXGEN"},

		CASE 42:  // SIEMENS
			{1, "SIEMENS MICRO K"},
			{2, "SITRANS L"},
			{3, "SIPAN PH"},
			{4, "SITRANS F"},
			{5, "SIPAN LF"},
			{6, "SIPAN O2"},
			{10, "SITRANS P HS"},
			{11, "SITRANS P DS"},
			{12, "SITRANS P ES"},
			{13, "SITRANS P MS"},
			{15, "SITRANS T 2K"},
			{16, "SITRANS TW"},
			{18, "SITRANS TK H"},
			{21, "SIPART PS2"},

		CASE 44:  // TOSHIBA
			{2, "AP3100"},
			{3, "AP3110"},
			{4, "AP3120"},
			{5, "AP3140"},
			{6, "AP3150"},
			{7, "AP3170"},
			{8, "AP3180"},
			{9, "AP3190"},
			{10, "LF220"},

		CASE 46:  // ROSEMOUNT ANALYTICAL
			{6, "1181pH"},
			{7, "1181Cond"},
			{10, "1054ApH"},
			{11, "1054ACond"},
			{12, "OXT4000"},
			{13, "WC 3000"},
			{14, "3081FG"},
			{15, "OPM 2000R"},
			{20, "3081pH"},
			{21, "3081Cond"},
			{22, "3081 81C"},
			{23, "3081 81T"},
			{80, "Model 54pH"},
			{81, "Model 54eC"},

		CASE 47:  // VALMET
			{1, "PSMART"},
			{60, "SMARTPULP"},
			{62, "MCAi"},

		CASE 48:  // FLOWSERVE
			{1, "LGX1200"},
			{2, "KAMMMER C2100"},

		CASE 50:  // VIATRAN
			{1, "970"},

		CASE 54:  // YAMATAKE HONEYWELL
			{1, "YHWFLOW"},

		CASE 55:  // YOKOGAWA
			{1, "YEWFLO"},
			{2, "YT200"},
			{3, "UNICOM"},
			{4, "EJA"},
			{5, "ADMAG AE"},
			{6, "AM11"},
			{8, "ADMAG SE"},
			{9, "YTA"},
			{10, "YTA70E"},
			{21, "PH202"},
			{64, "ROTAMASS"},

		CASE 58:  // EXAC
			{211, "8320"},
			{212, "SX5100"},

		CASE 59:  // KDG MOBREY
			{19, "4301"},
			{20, "3301"},
			{21, "MSP100"},
			{41, "MLT100"},

		CASE 61:  // PRINCO
			{1, "L4610"},

		CASE 62:  // SMAR
			{1, "LD301"},
			{2, "TT301"},

		CASE 63:  // ECKARDT
			{1, "TSV175"},
			{2, "DMU 130"},
			{3, "TI20"},
			{4, "SRD991"},
			{5, "DMU 140"},

		CASE 66:  // SAMSON
			{249, "3780"},

		CASE 67:  // SPARLING INSTRUMENTS
			{238, "626"},

		CASE 69:  // KROHNE
			{242, "ESKII"},
			{249, "BM70"},
			{248, "IFC080"},
			{247, "MFC08x"},
			{246, "IFC010"},
			{245, "UFC500"},
			{244, "IFC090"},
			{243, "IFC110"},
			{237, "VFM31"},

		CASE 77:  // WESTLOCK CONTROLS
			{1, "ICOT"},

		CASE 78:  // DREXELBROOK
			{2, "UNIVERSAL III"},

		CASE 79:  // SAAB TANK CONTROL
			{239, "TR PRO"},

		CASE 82:  // DRAEGER
			{1, "TEST"},
			{247, "POLYTRON2"},
			{237, "POLYTRON2 IR"},

		CASE 86:  // MAGNETROL
			{238, "MODEL 705"},
			{237, "MODEL 805"},
			{239, "SMARTEZ"},

		CASE 87:  // NELES JAMESBURY
			{239, "ND800"},
			{238, "ND800 PT"},

		CASE 88:  // MILLTRONICS
			{200, "86x PROBE"},
			{201, "IQ300"   },

		CASE 90:  // ANDERSON

		CASE 91:  // INOR
			{239, "MESO"},

		CASE 92:  // ROBERTSHAW
			{200, "EXCALIBUR 7000"},

		CASE 94:  // ACCUTECH
			{239, "AI1500"},

		CASE 96:  // KAMSTRUP
			{238, "FLEXBAR HRT"},
			{239, "FLEXTOP HRT"},

		CASE 97:  // KNICK
			{232, "2211CondI"},
			{234, "2211Cond"},
			{235, "2211PH"},

		CASE 101:  // MASONEILAN
			{200, "SVI"},
			{100, "HDLT"},

		CASE 102:  // BESTA
			{239, "CLS420"},

		CASE 103:  // OHMART
			{224, "XMTR"},

		CASE 104:  // HAROLD BECK AND SONS
			{1, "ESR D"},

		CASE 107:  // WIKA
			{239, "T32H"},

		CASE 108:  // BOPP AND REUTHER HEINRICHS
			{235, "UMC2"},
			{236, "ES"},
			{237, "VTX"},
			{239, "UST 01"},

		CASE 109:  // PR ELECTRONICS
			{239, "PR5335"},

		CASE 113:  // APPARATEBAU HUNDSBACH
			{238, "MT115"},

		CASE 114:  // DYNISCO
			{224, "IPX"},

		CASE 120:  // BURKERT
			{239, "8630"},

		CASE 124:  // GLI
			{238, "M33 53P"},
			{239, "M33 53C"},

		CASE 126:  // PMC
			{224, "SMT EL"},

		CASE 127:  // LABOM
			{224, "IPX"},

		CASE 129:  // TURBO
			{127, "INTERMAG TRANSMAG"},

		CASE 131:  // SMC
			{239, "F793 E701"},

		CASE 133:  // HUAKONG
			{127, "HK TT01"},

		CASE 239:  // HCF
			{235, "STD"},
			{236, "SAMPLE4"},
			{237, "SAMPLE3"},
			{238, "SAMPLE2"},
			{239, "SAMPLE1"},
		}

		{ 252, [unknown] },
	}
}

VARIABLE request_preambles
{
  HELP [number_of_request_preambles_help];
/*
  APPHELP "The valid range of values is dependant on the technology of"
	  " the Hardware of the Physical Layer. The magnitude of this number"
	  " includes the two preambles required by the Data Link Layer."
	  " NOTE- This variable can affect the Data Link Layer."
	  " HART_VAR:NUMBER RQUEST PREAM";
*/
  LABEL [number_of_request_preambles];
  HANDLING READ;
  CLASS HART;
  TYPE UNSIGNED_INTEGER
    {
	MIN_VALUE  2;
	MAX_VALUE  20;
    }
}

VARIABLE universal_revision
{
  HELP [universal_revision_help];
/*
  APPHELP "The variable universal_revision in effect defines for the"
	  " Master how to interpret the valid Universal Command set, and also"
	  " how to send and receive the Universal Commands. Therefore, this"
	  " variable must be obtained from a Command #0 response to be able to"
	  " interpret any Universal Command. Thus to properly interpret any"
	  " Burst Mode response, the Master should know the Universal Revision"
	  " of that Slave."
	  " "
	  " NOTE- The HART Revision is a variable that is not available via the"
	  " protocol. This Revision identifies the a point in time where all"
	  " HART Documents were recorded, and was made available to Field Device"
	  " Developers as a valid set of documents for which to design a Field"
	  " Device to. Field Device Developers then can not pick and choose a"
	  " HART Document set at random."

	  " NOTE- For HART Revision <= 5 the following HART Specification"
	  " Revisions are not available via the protocol for the Physical Layer:"
	  " 'HART Physical Layer Specification'."

	  " NOTE- For HART Revision <= 5 the following HART Specification"
	  " Revisions are not available via the protocol for the Data Link"
	  " Layer: 'HART Data Link Layer Specification'."

	  " NOTE- For HART Revision <= 5 the following HART Specification"
	  " Revisions are not available via the protocol for the Application"
	  " Layer: 'HART Command Summary Information', 'HART Common"
	  " Practice Command Specification', 'HART Common Tables', 'HART"
	  " Appendix 1- Command Specific Response Code Definitions'."

	  " NOTE- A Field Device Description implicitly encodes the required"
	  " Application Layer Revisions that are required to communicate with"
	  " that Field Device."

	  " NOTE- If the Master attempts to communicate with a Field Device"
	  " that it does not have a Field Device Description for, it technically"
	  " has no way to ascertain the exact Common Practice Revision of Common"
	  " Tables Revision to utilize. It is possible by the variable"
	  " universal_revision to ascertain a minimum Common Practice Revision"
	  " and Common Tables Revision."

	  " NOTE- Value 254 is 'Reserved'."
	  " HART_VAR:UNIV CMD REV";
*/
  LABEL [universal_revision];
  HANDLING READ;
  CLASS HART;
  TYPE UNSIGNED_INTEGER
    {
	MAX_VALUE  253;
    }
}

VARIABLE transmitter_revision
{
  HELP [field_device_revision_help];
/*
  APPHELP "This variable in effect defines aspects of the Application"
	  " Layer, Data Link Layer, and Physical Layer, in that a HART Revision"
	  " was implicitly conformed to in the design of this Field Device"
	  " NOTE- Value 254 is 'Reserved'."
	  " HART_VAR:TRANS SPEC REV";
*/
  LABEL [transmitter_revision];
  HANDLING READ;
  CLASS HART;
  TYPE UNSIGNED_INTEGER
    {
	MAX_VALUE  253;
    }
}

VARIABLE software_revision
{
  HELP [field_device_software_revision_help];
/*
  APPHELP "For a specific value of the variable transmitter_revision the"
	  " variable software_revision be initiated at a value of '1'. This"
	  " count should be incremented for each released software modification."
	  " If the variable transmitter_revision is incremented the variable"
	  " software_revision be initiated once again to a value of '1', and so"
	  " forth. This variable could potentially be utilized as a handle for"
	  " recalling Field Devices with a software discrepancy."
	  " NOTE- Value 254 is 'Reserved'."
	  " HART_VAR:SOFT REV";
*/
  LABEL [software_revision];
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER
    {
	MAX_VALUE  253;
    }
}

VARIABLE hardware_revision
{
  LABEL [hardware_revision];
  HELP [hardware_revision_help];
/*
  APPHELP "The Field Device Hardware revision should be utilized"
	  " to track what ever level of modifications are desired. However,"
	  " please note the limited number of possible revisions. Also please"
	  " note that in many hardware / software configurations the software"
	  " can be removed from the hardware to be upgraded, moved, etc.. In"
	  " this situation the variable hardware_revision must not reside in the"
	  " software, but should be readable via from the actual hardware"
	  " itself."
	  " NOTE- Value 15 is Reserved for the Field Device Hardware Revision"
	  " component called the variable hardware_revision."
	  " HART_VAR:HARD REV";
*/
  HANDLING READ;
  CLASS DEVICE;
  TYPE UNSIGNED_INTEGER;
}

VARIABLE physical_signaling_code
{
  LABEL [physical_signalling_code];
  HELP	[physical_signalling_code_help];
/*
  APPHELP "";
*/
  HANDLING READ;
  CLASS DEVICE;
  TYPE ENUMERATED
  {
      { 0, [bell_202_current] },
      { 1, [bell_202_voltage] },
      { 2, [rs_485] },
      { 3, [rs_232], [rs_232_help] },
      { 6, [special] }
  }
}

VARIABLE device_flags
{
  HELP [field_device_flags_help];
/*
  APPHELP "NOTE- The enumeration '1' does not conform to the help description."
	  " HART_VAR:FLAGS";
*/
  LABEL [device_flags];
  HANDLING READ;
  CLASS HART;
  TYPE BIT_ENUMERATED
  {
      { 0x01, [multi_sensor_fld_dev], [multi_sensor_fld_dev_help] },
      { 0x02, [EEPROM_Ctrl] },
      { 0x04, [protocol_bridge_device] }
  }
}

VARIABLE device_id
{
  HELP [field_device_identification_help];
/*
  APPHELP "This variable should be written into the Field Device in the"
	  " manufacturing process. This variable should be initiated at value"
	  " '1' and incremented for each Field Device created that has the"
	  " same set of values for the variables manufacturer_id and"
	  " device_type."
	  " HART_VAR:DEVICE ID NUMBER";
*/
  LABEL [device_identification];
  HANDLING READ;
  CLASS HART;
  TYPE UNSIGNED_INTEGER (3);
}

COMMAND read_unique_identifier
{
	NUMBER 0;

	OPERATION READ;

	TRANSACTION
		{
			REQUEST
				{}

			REPLY
				{
					response_code, device_status,254, manufacturer_id, device_type,
					request_preambles, universal_revision, transmitter_revision,
					software_revision,hardware_revision <0xf8>, physical_signaling_code <0x07>,
					device_flags, device_id

				}
		}

	RESPONSE_CODES
		{
			0,	SUCCESS,	[no_command_specific_errors];
			6,	MISC_ERROR,	[xmtr_specific_command_error];
			16,	MODE_ERROR,	[access_restricted];
		}
}

