// SIHASTIDENT01.inc
// Description: Identification Check for HART
// Copyright (C) Siemens AG (1999-2003). All Rights Reserved.
// $Revision:   1.11  $
// $Date:   Jan 2 2003 $


#include "Manufacturer_List.h"



#define	ID_CHECK_ABORT			0
#define	ID_CHECK_SUCCESS		1

#define ID_STATUS_SIZE			3		/* size of status array				  */
#define ID_STATUS_COMM_STATUS	1

#define	ID_FC_ERROR				3000


#define	COMMAND_ID_READ_UNIQUE_IDENTIFIER		0
#define	COMMAND_ID_READ_TAG_DESCRIPTOR_DATE		13
#define	COMMAND_ID_READ_PV_OUTPUT_INFO			15


// --- Identcheck and WriteProtectionCheck use features only supported in 5.0.2 !

#ifdef _V502_

// enable ident check
#define ENABLE_IDENTCHECK

// enable WriteProtection check
#define ENABLE_WRITEPROTECTIONCHECK

// Additional ITEMS for Options Menu 
// #define DEBUG_OPTION1	OfflineDialog_DebugDeviceIdentification

#endif


#ifndef _V510_
#define LOG_MESSAGE(priority, text) _TRACE(text) 
#endif



// --- IdentCheck DEBUG Dialog ------------------------------------------

#ifdef DEBUG_OPTION1

MENU OfflineDialog_DebugDeviceIdentification
{
	LABEL	"Test_Identification";
	ITEMS
	{
		Page_DebugDeviceIdentification
	}
}



MENU Page_DebugDeviceIdentification
{
	LABEL	"Test_Identification";
	ITEMS
	{
		group_identcheck_dd,
		SEPARATOR,
		group_identcheck_device,
	}
}


MENU group_identcheck_dd
{
	LABEL "Offline data" ;
	ITEMS
	{
		tag (READ_ONLY),
		dd_manufacturer_id,
		dd_device_type,
		device_id,
		dd_device_revision
	}
}

MENU group_identcheck_device
{
	LABEL "Device" ;
	ITEMS
	{
		id_tag,
		id_manufacturer_id,
		id_device_type,
		id_device_id,
		id_device_revision,

#ifdef ENABLE_IDENTCHECK
		std_CheckDeviceIdentification,
		std_CheckDeviceIdentificationUpload,
		std_CheckDeviceIdentificationDownload,
#endif
		ret_CheckDeviceIdentification
	}
}

#endif


// --- IdentCheck VARIABLES ------------------------------------------

VARIABLE	ret_CheckDeviceIdentification
{
	LABEL		"Result";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	ID_CHECK_SUCCESS ;
	}
	HANDLING	READ;
}

VARIABLE id_Method_In_SilentMode
{
    LABEL		"Method in Silent Mode";
    CLASS		LOCAL;
    TYPE		ENUMERATED
    {
	    DEFAULT_VALUE	0x00;	
	    { 0x00, [no]	},
        { 0x01, [yes]	}
	}
    HANDLING	READ;
}

VARIABLE	id_firstCheck
{
	LABEL		"id_firstCheck";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	1;
	}
	HANDLING	READ;
}

VARIABLE	id_status
{
	LABEL		"";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	ID_CHECK_ABORT;
	}
	HANDLING	READ;
}

VARIABLE	id_dummy_dword
{
	LABEL		"";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE	id_dummy_word
{
	LABEL		"";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}


VARIABLE	id_dummy_byte
{
	LABEL		"";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}


VARIABLE	id_dummy_float
{
	LABEL		"";
	CLASS		LOCAL;
	TYPE		FLOAT ;
	HANDLING	READ;
}


VARIABLE id_manufacturer_id
{
	HELP [manufacturer_id_code_help];
	LABEL [manufacturer_id];
	HANDLING READ;
	CLASS LOCAL ;
	TYPE ENUMERATED
    {
	  DEFAULT_VALUE 252 ;

		MANUFACTURER_LIST
    }
}

VARIABLE id_device_type
{
	LABEL		[device_type];
	HELP		[manufacturers_device_type_help];
	HANDLING	READ;
	CLASS		LOCAL ;
	TYPE		ENUMERATED (1)
	{
		SELECT( id_manufacturer_id )
		{ 
		CASE 10:  // BROOKS INSTRUMENT
			{1, "TRI20"},
			{2, "38XXVA"},
			{3, "99XX OVAL"},

		CASE 14:  // DELTA
			{1, "HT"},

		CASE 17:  // ENDRESS HAUSER
			{0x03,"Prosonic / FMU 860"},
			{0x04,"Prosonic / FMU 861"},
			{0x05,"Prosonic / FMU 862"},
			{0x06,"Micropilot I / FMR 13x"},
			{0x07,"Cerabar S / PMx x3x"},
			{0x08,"Multicap / FEC 12"},
			{0x09,"Deltabar S / xMD x3x"},
			{0x0A,"Prosonic T / FMU x3x"},
			{0x0B,"Deltapilot S / DB 5x"},
			{0x0C,"Micropilot II / FMR 23x"},
			{0x0D,"Levelflex / FMP 2xx"},
			{0x0E,"Cerabar M / PMx 4x"},
			{0x0F,"Micropilot M / FMR 2xx"},
			{0x10,"Micropilot S / FMR 53x"},
			{0x11,"Prosonic M / FMU 4x"},
			{0x12,"Levelflex M / FMP 40"},
			{0x32,"Promag / 33"},
			{0x33,"Prowirl / 70"},
			{0x34,"Promass / 63"},
			{0x35,"Promag / 39"},
			{0x36,"Promag / 35 S"},
			{0x37,"Prowirl / 77"},
			{0x39,"Promass / 60"},
			{0x40,"Prosonic Flow / DMU93"},
			{0x41,"Promag / 50"},
			{0x42,"Promag / 53"},
			{0x43,"Promag / 51"},
			{0x45,"Promag / 10"},
			{0x46,"Promag / 23"},
			{0x50,"Promass / 80"},
			{0x51,"Promass / 83"},
			{0x53,"Promass / 40"},
			{0x56,"Prowirl / 72"},
			{0x57,"Prowirl / 73"},
			{0x58,"Prosonic Flow / 90"},
			{0x59,"Prosonic Flow / 93"},
			{0x78,"Omnigrad / TMD 832"},
			{0x79,"Omnigrad / TMD 833"},
			{0x7C,"Omnigrad / TMD 842"},
			{0x8C,"Mypro PH / CPM 431"},
			{0x8D,"Mypro Cond. C / CLx 431"},
			{0x8E,"Mypro Cond. I / CLx 431"},
			{0x91,"Liquisys M PH / CPM 2x3"},
			{0x92,"Liquisys M Cond. I / CLM 2x3"},
			{0x93,"Liquisys M Cond. C / CLM 2x3"},
			{0x94,"Liquisys M DO / COM 2x3"},
			{0x95,"Liquisys M Turbidity / CUM 2x3"},
			{0x96,"Liquisys M Chlorine / CCM 2x3"},
			{0x97,"Smartec S / CLD 132"},
			{0xC8,"iTemp / TMT 182"},
			{0xC9,"iTemp / TMT 122"},
			{0xCA,"iTemp / TMT 162"},
			  {100, "AT70"},
			  {181, "NMT530"},
			  {255, "FIELDTEST"},

		CASE 18:  // BAILEY FISCHER AND PORTER
			{7, "50XM2000"},
			{8, "50XE4000"},
			{14, "50VT1000"},
			{15, "50VM1000"},
			{25, "50XM1000"},
			{26, "50SM1000"},
			{66, "PTH"},

		CASE 19:  // FISHER CONTROLS
			{1, "DT"},
			{2, "DVC"},

		CASE 20:  // FOXBORO
			{41, "IMT25"},
			{46, "IA PRESSURE"},
			{51, "ITVORTEX"},

		CASE 21:  // FUJI
			{1, "FCX"},

		CASE 22:  // HARTMANN BRAUN
			{3, "TEU471"},
			{4, "TEU421"},
			{5, "TEU211"},
			{6, "TS11"},
			{64, "TZID"},
			{65, "TZIDC"},
			{133, "AS800"},

		CASE 23:  // HONEYWELL
			{1, "ST3000"},
			{3, "HWFLOW"},
			{4, "STT250"},

		CASE 25:  // KAY RAY SENSALL
			{8, "4050"},
			{9, "3680"},
			{10, "4790"},
			{15, "3280"},

		CASE 26:  // KENT
			{1, "KSX"},
			{2, "PX"},
			{8, "KST"},
			{10, "658T"},
			{12, "653S"},
			{16, "VALVE"},
			{24, "FLOW"},
			{32, "LEVEL"},

		CASE 31:  // MICRO MOTION
			{7, "9712"},
			{20, "9720"},
			{21, "9739"},
			{30, "9701"},

		CASE 32:  // MOORE INDUSTRIES
			{1, "TRZ"},
			{3, "THZ"},

		CASE 33:  // MOORE PRODUCTS
			{1, "340 A"},
			{2, "340 B"},
			{3, "344"},
			{5, "341"},
			{6, "340 A2"},
			{8, "340 B2"},
			{9, "344 2"},
			{10, "340 S"},
			{11, "343"},
			{12, "760 D"},
			{13, "345"},

		CASE 38:  // ROSEMOUNT
			{1, "3051"},
			{2, "3044"},
			{3, "1151s"},
			{4, "8712"},
			{5, "2001"},
			{6, "3051C"},
			{11, "3001L"},
			{12, "8712H"},
			{13, "3044C"},
			{14, "3001C"},
			{15, "3051CLP"},
			{16, "8800"},
			{17, "3201"},
			{18, "1152"},
			{19, "3202"},
			{20, "3001S"},
			{22, "3095MV"},
			{24, "644"},
			{25, "3144"},
			{26, "3244"},
			{28, "APEX"},
			{29, "TRILOOP"},
			{30, "3095C"},
			{35, "2088"},
			{36, "PROBAR"},
			{39, "2090"},
			{40, "PROBAR UC"},
			{127, "HART COMMUNICATOR"},
			{128, "UNIVERSAL XMTR"},

		CASE 39:  // PEEK MEASUREMENT
			{0, "FD900"},

		CASE 40:  // SCHLUMBERGER
			{1, "NEXGEN"},

		CASE 42:  // SIEMENS
			{1, "SIEMENS MICRO K"},
			{2, "SITRANS L"},
			{3, "SIPAN PH"},
			{4, "SITRANS F"},
			{5, "SIPAN LF"},
			{6, "SIPAN O2"},
			{7, "SITRANS LR"},
			{10, "SITRANS P HS"},
			{11, "SITRANS P DS"},
			{12, "SITRANS P ES"},
			{13, "SITRANS P MS"},
			{15, "SITRANS T 2K"},
			{16, "SITRANS TW"},
			{18, "SITRANS TK H"},
			{21, "SIPART PS2"},

		CASE 44:  // TOSHIBA
			{2, "AP3100"},
			{3, "AP3110"},
			{4, "AP3120"},
			{5, "AP3140"},
			{6, "AP3150"},
			{7, "AP3170"},
			{8, "AP3180"},
			{9, "AP3190"},
			{10, "LF220"},

		CASE 46:  // ROSEMOUNT ANALYTICAL
			{6, "1181pH"},
			{7, "1181Cond"},
			{10, "1054ApH"},
			{11, "1054ACond"},
			{12, "OXT4000"},
			{13, "WC 3000"},
			{14, "3081FG"},
			{15, "OPM 2000R"},
			{20, "3081pH"},
			{21, "3081Cond"},
			{22, "3081 81C"},
			{23, "3081 81T"},
			{80, "Model 54pH"},
			{81, "Model 54eC"},

		CASE 47:  // VALMET
			{1, "PSMART"},
			{60, "SMARTPULP"},
			{62, "MCAi"},

		CASE 48:  // FLOWSERVE
			{1, "LGX1200"},
			{2, "KAMMMER C2100"},

		CASE 50:  // VIATRAN
			{1, "970"},

		CASE 54:  // YAMATAKE HONEYWELL
			{1, "YHWFLOW"},

		CASE 55:  // YOKOGAWA
			{1, "YEWFLO"},
			{2, "YT200"},
			{3, "UNICOM"},
			{4, "EJA"},
			{5, "ADMAG AE"},
			{6, "AM11"},
			{8, "ADMAG SE"},
			{9, "YTA"},
			{10, "YTA70E"},
			{21, "PH202"},
			{64, "ROTAMASS"},

		CASE 58:  // EXAC
			{211, "8320"},
			{212, "SX5100"},

		CASE 59:  // KDG MOBREY
			{19, "4301"},
			{20, "3301"},
			{21, "MSP100"},
			{41, "MLT100"},

		CASE 61:  // PRINCO
			{1, "L4610"},

		CASE 62:  // SMAR
			{1, "LD301"},
			{2, "TT301"},

		CASE 63:  // ECKARDT
			{1, "TSV175"},
			{2, "DMU 130"},
			{3, "TI20"},
			{4, "SRD991"},
			{5, "DMU 140"},

		CASE 66:  // SAMSON
			{249, "3780"},

		CASE 67:  // SPARLING INSTRUMENTS
			{238, "626"},

		CASE 69:  // KROHNE
			{242, "ESKII"},
			{249, "BM70"},
			{248, "IFC080"},
			{247, "MFC08x"},
			{246, "IFC010"},
			{245, "UFC500"},
			{244, "IFC090"},
			{243, "IFC110"},
			{237, "VFM31"},

		CASE 77:  // WESTLOCK CONTROLS
			{1, "ICOT"},

		CASE 78:  // DREXELBROOK
			{2, "UNIVERSAL III"},

		CASE 79:  // SAAB TANK CONTROL
			{239, "TR PRO"},

		CASE 82:  // DRAEGER
			{1, "TEST"},
			{247, "POLYTRON2"},
			{237, "POLYTRON2 IR"},

		CASE 86:  // MAGNETROL
			{238, "MODEL 705"},
			{237, "MODEL 805"},
			{239, "SMARTEZ"},

		CASE 87:  // NELES JAMESBURY
			{239, "ND800"},
			{238, "ND800 PT"},

		CASE 88:  // MILLTRONICS
			{200, "86x PROBE"},

		CASE 90:  // ANDERSON

		CASE 91:  // INOR
			{239, "MESO"},

		CASE 92:  // ROBERTSHAW
			{200, "EXCALIBUR 7000"},

		CASE 94:  // ACCUTECH
			{239, "AI1500"},

		CASE 96:  // KAMSTRUP
			{238, "FLEXBAR HRT"},
			{239, "FLEXTOP HRT"},

		CASE 97:  // KNICK
			{232, "2211CondI"},
			{234, "2211Cond"},
			{235, "2211PH"},

		CASE 101:  // MASONEILAN
			{200, "SVI"},
			{100, "HDLT"},

		CASE 102:  // BESTA
			{239, "CLS420"},

		CASE 103:  // OHMART
			{224, "XMTR"},

		CASE 104:  // HAROLD BECK AND SONS
			{1, "ESR D"},

		CASE 107:  // WIKA
			{239, "T32H"},

		CASE 108:  // BOPP AND REUTHER HEINRICHS
			{235, "UMC2"},
			{236, "ES"},
			{237, "VTX"},
			{239, "UST 01"},

		CASE 109:  // PR ELECTRONICS
			{239, "PR5335"},

		CASE 113:  // APPARATEBAU HUNDSBACH
			{238, "MT115"},

		CASE 114:  // DYNISCO
			{224, "IPX"},

		CASE 120:  // BURKERT
			{239, "8630"},

		CASE 124:  // GLI
			{238, "M33 53P"},
			{239, "M33 53C"},

		CASE 126:  // PMC
			{224, "SMT EL"},

		CASE 127:  // LABOM
			{224, "IPX"},

		CASE 129:  // TURBO
			{127, "INTERMAG TRANSMAG"},

		CASE 131:  // SMC
			{239, "F793 E701"},

		CASE 133:  // HUAKONG
			{127, "HK TT01"},

		CASE 239:  // HCF
			{235, "STD"},
			{236, "SAMPLE4"},
			{237, "SAMPLE3"},
			{238, "SAMPLE2"},
			{239, "SAMPLE1"},
		}

		{ 252, [unknown] },
	}
}


id_device_type				LIKE VARIABLE	device_type
{
	REDEFINE	CLASS		LOCAL;
}


VARIABLE id_device_id
{
  HELP [field_device_identification_help];
  LABEL [device_identification];
  HANDLING READ;
  CLASS LOCAL ;
  TYPE UNSIGNED_INTEGER (3);
}


id_device_revision		LIKE VARIABLE	transmitter_revision
{
	REDEFINE	CLASS		LOCAL;
}


id_tag						LIKE VARIABLE	tag
{
	REDEFINE	CLASS		LOCAL;
}


id_software_revision LIKE VARIABLE software_revision
{
	REDEFINE	CLASS		LOCAL;
}


VARIABLE id_write_protect
{
  HELP [write_protect_mode_help];
/*
  APPHELP "Common uses for the write_protect variable are to limit user access"
	  " for Field Devices installed in custody transfer applications."
	  " HART_VAR:WRITE PROT CODE";
*/
  LABEL [write_protect];
  HANDLING READ;
  CLASS LOCAL;
  TYPE ENUMERATED
    {
		{ 0,	[not_write_protected] },
		{ 1,	[write_protected] },
		{ 250,	[not_used] },
		{ 251,	[none] },
		{ 252,	[unknown] },
		{ 253,	[special] }
    }
}


dd_device_revision LIKE VARIABLE transmitter_revision
{
	REDEFINE	CLASS		LOCAL;
}

dd_manufacturer_id			LIKE VARIABLE	id_manufacturer_id
{
	REDEFINE	CLASS		LOCAL;
	REDEFINE	HANDLING READ & WRITE ;
}

VARIABLE dd_device_type
{
	LABEL		[device_type];
	HELP		[manufacturers_device_type_help];
	HANDLING	READ & WRITE ;
	CLASS		LOCAL ;
	TYPE		ENUMERATED (1)
	{
		SELECT( dd_manufacturer_id )
		{ 
		CASE 10:  // BROOKS INSTRUMENT
			{1, "TRI20"},
			{2, "38XXVA"},
			{3, "99XX OVAL"},

		CASE 14:  // DELTA
			{1, "HT"},

		CASE 17:  // ENDRESS HAUSER
			{0x03,"Prosonic / FMU 860"},
			{0x04,"Prosonic / FMU 861"},
			{0x05,"Prosonic / FMU 862"},
			{0x06,"Micropilot I / FMR 13x"},
			{0x07,"Cerabar S / PMx x3x"},
			{0x08,"Multicap / FEC 12"},
			{0x09,"Deltabar S / xMD x3x"},
			{0x0A,"Prosonic T / FMU x3x"},
			{0x0B,"Deltapilot S / DB 5x"},
			{0x0C,"Micropilot II / FMR 23x"},
			{0x0D,"Levelflex / FMP 2xx"},
			{0x0E,"Cerabar M / PMx 4x"},
			{0x0F,"Micropilot M / FMR 2xx"},
			{0x10,"Micropilot S / FMR 53x"},
			{0x11,"Prosonic M / FMU 4x"},
			{0x12,"Levelflex M / FMP 40"},
			{0x32,"Promag / 33"},
			{0x33,"Prowirl / 70"},
			{0x34,"Promass / 63"},
			{0x35,"Promag / 39"},
			{0x36,"Promag / 35 S"},
			{0x37,"Prowirl / 77"},
			{0x39,"Promass / 60"},
			{0x40,"Prosonic Flow / DMU93"},
			{0x41,"Promag / 50"},
			{0x42,"Promag / 53"},
			{0x43,"Promag / 51"},
			{0x45,"Promag / 10"},
			{0x46,"Promag / 23"},
			{0x50,"Promass / 80"},
			{0x51,"Promass / 83"},
			{0x53,"Promass / 40"},
			{0x56,"Prowirl / 72"},
			{0x57,"Prowirl / 73"},
			{0x58,"Prosonic Flow / 90"},
			{0x59,"Prosonic Flow / 93"},
			{0x78,"Omnigrad / TMD 832"},
			{0x79,"Omnigrad / TMD 833"},
			{0x7C,"Omnigrad / TMD 842"},
			{0x8C,"Mypro PH / CPM 431"},
			{0x8D,"Mypro Cond. C / CLx 431"},
			{0x8E,"Mypro Cond. I / CLx 431"},
			{0x91,"Liquisys M PH / CPM 2x3"},
			{0x92,"Liquisys M Cond. I / CLM 2x3"},
			{0x93,"Liquisys M Cond. C / CLM 2x3"},
			{0x94,"Liquisys M DO / COM 2x3"},
			{0x95,"Liquisys M Turbidity / CUM 2x3"},
			{0x96,"Liquisys M Chlorine / CCM 2x3"},
			{0x97,"Smartec S / CLD 132"},
			{0xC8,"iTemp / TMT 182"},
			{0xC9,"iTemp / TMT 122"},
			{0xCA,"iTemp / TMT 162"},
			  {100, "AT70"},
			  {181, "NMT530"},
			  {255, "FIELDTEST"},

		CASE 18:  // BAILEY FISCHER AND PORTER
			{7, "50XM2000"},
			{8, "50XE4000"},
			{14, "50VT1000"},
			{15, "50VM1000"},
			{25, "50XM1000"},
			{26, "50SM1000"},
			{66, "PTH"},

		CASE 19:  // FISHER CONTROLS
			{1, "DT"},
			{2, "DVC"},

		CASE 20:  // FOXBORO
			{41, "IMT25"},
			{46, "IA PRESSURE"},
			{51, "ITVORTEX"},

		CASE 21:  // FUJI
			{1, "FCX"},

		CASE 22:  // HARTMANN BRAUN
			{3, "TEU471"},
			{4, "TEU421"},
			{5, "TEU211"},
			{6, "TS11"},
			{64, "TZID"},
			{65, "TZIDC"},
			{133, "AS800"},

		CASE 23:  // HONEYWELL
			{1, "ST3000"},
			{3, "HWFLOW"},
			{4, "STT250"},

		CASE 25:  // KAY RAY SENSALL
			{8, "4050"},
			{9, "3680"},
			{10, "4790"},
			{15, "3280"},

		CASE 26:  // KENT
			{1, "KSX"},
			{2, "PX"},
			{8, "KST"},
			{10, "658T"},
			{12, "653S"},
			{16, "VALVE"},
			{24, "FLOW"},
			{32, "LEVEL"},

		CASE 31:  // MICRO MOTION
			{7, "9712"},
			{20, "9720"},
			{21, "9739"},
			{30, "9701"},

		CASE 32:  // MOORE INDUSTRIES
			{1, "TRZ"},
			{3, "THZ"},

		CASE 33:  // MOORE PRODUCTS
			{1, "340 A"},
			{2, "340 B"},
			{3, "344"},
			{5, "341"},
			{6, "340 A2"},
			{8, "340 B2"},
			{9, "344 2"},
			{10, "340 S"},
			{11, "343"},
			{12, "760 D"},
			{13, "345"},

		CASE 38:  // ROSEMOUNT
			{1, "3051"},
			{2, "3044"},
			{3, "1151s"},
			{4, "8712"},
			{5, "2001"},
			{6, "3051C"},
			{11, "3001L"},
			{12, "8712H"},
			{13, "3044C"},
			{14, "3001C"},
			{15, "3051CLP"},
			{16, "8800"},
			{17, "3201"},
			{18, "1152"},
			{19, "3202"},
			{20, "3001S"},
			{22, "3095MV"},
			{24, "644"},
			{25, "3144"},
			{26, "3244"},
			{28, "APEX"},
			{29, "TRILOOP"},
			{30, "3095C"},
			{35, "2088"},
			{36, "PROBAR"},
			{39, "2090"},
			{40, "PROBAR UC"},
			{127, "HART COMMUNICATOR"},
			{128, "UNIVERSAL XMTR"},

		CASE 39:  // PEEK MEASUREMENT
			{0, "FD900"},

		CASE 40:  // SCHLUMBERGER
			{1, "NEXGEN"},

		CASE 42:  // SIEMENS
			{1, "SIEMENS MICRO K"},
			{2, "SITRANS L"},
			{3, "SIPAN PH"},
			{4, "SITRANS F"},
			{5, "SIPAN LF"},
			{6, "SIPAN O2"},
			{7, "SITRANS LR"},
			{10, "SITRANS P HS"},
			{11, "SITRANS P DS"},
			{12, "SITRANS P ES"},
			{13, "SITRANS P MS"},
			{15, "SITRANS T 2K"},
			{16, "SITRANS TW"},
			{18, "SITRANS TK H"},
			{21, "SIPART PS2"},

		CASE 44:  // TOSHIBA
			{2, "AP3100"},
			{3, "AP3110"},
			{4, "AP3120"},
			{5, "AP3140"},
			{6, "AP3150"},
			{7, "AP3170"},
			{8, "AP3180"},
			{9, "AP3190"},
			{10, "LF220"},

		CASE 46:  // ROSEMOUNT ANALYTICAL
			{6, "1181pH"},
			{7, "1181Cond"},
			{10, "1054ApH"},
			{11, "1054ACond"},
			{12, "OXT4000"},
			{13, "WC 3000"},
			{14, "3081FG"},
			{15, "OPM 2000R"},
			{20, "3081pH"},
			{21, "3081Cond"},
			{22, "3081 81C"},
			{23, "3081 81T"},
			{80, "Model 54pH"},
			{81, "Model 54eC"},

		CASE 47:  // VALMET
			{1, "PSMART"},
			{60, "SMARTPULP"},
			{62, "MCAi"},

		CASE 48:  // FLOWSERVE
			{1, "LGX1200"},
			{2, "KAMMMER C2100"},

		CASE 50:  // VIATRAN
			{1, "970"},

		CASE 54:  // YAMATAKE HONEYWELL
			{1, "YHWFLOW"},

		CASE 55:  // YOKOGAWA
			{1, "YEWFLO"},
			{2, "YT200"},
			{3, "UNICOM"},
			{4, "EJA"},
			{5, "ADMAG AE"},
			{6, "AM11"},
			{8, "ADMAG SE"},
			{9, "YTA"},
			{10, "YTA70E"},
			{21, "PH202"},
			{64, "ROTAMASS"},

		CASE 58:  // EXAC
			{211, "8320"},
			{212, "SX5100"},

		CASE 59:  // KDG MOBREY
			{19, "4301"},
			{20, "3301"},
			{21, "MSP100"},
			{41, "MLT100"},

		CASE 61:  // PRINCO
			{1, "L4610"},

		CASE 62:  // SMAR
			{1, "LD301"},
			{2, "TT301"},

		CASE 63:  // ECKARDT
			{1, "TSV175"},
			{2, "DMU 130"},
			{3, "TI20"},
			{4, "SRD991"},
			{5, "DMU 140"},

		CASE 66:  // SAMSON
			{249, "3780"},

		CASE 67:  // SPARLING INSTRUMENTS
			{238, "626"},

		CASE 69:  // KROHNE
			{242, "ESKII"},
			{249, "BM70"},
			{248, "IFC080"},
			{247, "MFC08x"},
			{246, "IFC010"},
			{245, "UFC500"},
			{244, "IFC090"},
			{243, "IFC110"},
			{237, "VFM31"},

		CASE 77:  // WESTLOCK CONTROLS
			{1, "ICOT"},

		CASE 78:  // DREXELBROOK
			{2, "UNIVERSAL III"},

		CASE 79:  // SAAB TANK CONTROL
			{239, "TR PRO"},

		CASE 82:  // DRAEGER
			{1, "TEST"},
			{247, "POLYTRON2"},
			{237, "POLYTRON2 IR"},

		CASE 86:  // MAGNETROL
			{238, "MODEL 705"},
			{237, "MODEL 805"},
			{239, "SMARTEZ"},

		CASE 87:  // NELES JAMESBURY
			{239, "ND800"},
			{238, "ND800 PT"},

		CASE 88:  // MILLTRONICS
			{200, "86x PROBE"},

		CASE 90:  // ANDERSON

		CASE 91:  // INOR
			{239, "MESO"},

		CASE 92:  // ROBERTSHAW
			{200, "EXCALIBUR 7000"},

		CASE 94:  // ACCUTECH
			{239, "AI1500"},

		CASE 96:  // KAMSTRUP
			{238, "FLEXBAR HRT"},
			{239, "FLEXTOP HRT"},

		CASE 97:  // KNICK
			{232, "2211CondI"},
			{234, "2211Cond"},
			{235, "2211PH"},

		CASE 101:  // MASONEILAN
			{200, "SVI"},
			{100, "HDLT"},

		CASE 102:  // BESTA
			{239, "CLS420"},

		CASE 103:  // OHMART
			{224, "XMTR"},

		CASE 104:  // HAROLD BECK AND SONS
			{1, "ESR D"},

		CASE 107:  // WIKA
			{239, "T32H"},

		CASE 108:  // BOPP AND REUTHER HEINRICHS
			{235, "UMC2"},
			{236, "ES"},
			{237, "VTX"},
			{239, "UST 01"},

		CASE 109:  // PR ELECTRONICS
			{239, "PR5335"},

		CASE 113:  // APPARATEBAU HUNDSBACH
			{238, "MT115"},

		CASE 114:  // DYNISCO
			{224, "IPX"},

		CASE 120:  // BURKERT
			{239, "8630"},

		CASE 124:  // GLI
			{238, "M33 53P"},
			{239, "M33 53C"},

		CASE 126:  // PMC
			{224, "SMT EL"},

		CASE 127:  // LABOM
			{224, "IPX"},

		CASE 129:  // TURBO
			{127, "INTERMAG TRANSMAG"},

		CASE 131:  // SMC
			{239, "F793 E701"},

		CASE 133:  // HUAKONG
			{127, "HK TT01"},

		CASE 239:  // HCF
			{235, "STD"},
			{236, "SAMPLE4"},
			{237, "SAMPLE3"},
			{238, "SAMPLE2"},
			{239, "SAMPLE1"},

		CASE 252:	// unbekannt
			{0, " "},
			{11, " "},
			{252, " "} 
		}

		{ 252, [unknown] },
	}
}



// --- IdentCheck METHODs ------------------------------------------

#ifdef ENABLE_IDENTCHECK

METHOD	std_CheckDeviceIdentification
{
	LABEL		"std_CheckDeviceIdentification";
	CLASS		INPUT;
	ACCESS		OFFLINE;
	DEFINITION
	{
		int  iResult ;
		char szTrace[] ;
		char sz[] ;
		char sz1[] ;
		char sz2[] ;
		char sz3[] ;
		char sz4[] ;
		char sz5[] ;
		char szChoice[] ;
		long var_id[10] ;
		long lDevice_Id ;
		long var_idDevice_Id ;

		int bOK ;
		ret_CheckDeviceIdentification	= ID_CHECK_ABORT ;

		_TRACE("std_CheckDeviceIdentification") ;

		var_idDevice_Id = VARID(device_id) ;

		if( var_idDevice_Id != 0 )
		{
			lDevice_Id = lvar_value(device_id) ;
		}
		else
		{
			lDevice_Id = lvar_value(final_assembly_number) ;
			var_idDevice_Id = VARID(final_assembly_number) ;
			szTrace = "*** Rev 4 DD (final_assembly_number (VARID " 
						+ itoa(var_idDevice_Id)
						+ ") used) !" ;
			_TRACE(szTrace) ;
		}

		bOK = 1 ;

		iResult = ID_FC_ERROR;
		while (iResult >= ID_FC_ERROR)
		{
			id_command_num = COMMAND_ID_READ_UNIQUE_IDENTIFIER;
			iResult = ReadCommand(id_read_unique_identifier) ;
	
			if( iResult < ID_FC_ERROR )
			{
				id_command_num = COMMAND_ID_READ_TAG_DESCRIPTOR_DATE;
				iResult = ReadCommand(id_read_tag_descriptor_date);
			}
			id_command_num = id_command_num.DEFAULT_VALUE;

			if (iResult >= ID_FC_ERROR)
			{
				if (id_Method_In_SilentMode == 0)
					ACKNOWLEDGE([IdentCheckCommProblem]);
				else
					process_abort();
			}
		}

		
		sz1 = id_tag ;
		szTrace = "Device found: Man " 
					+ itoa(ivar_value(id_manufacturer_id))
					+ " DeviceType "
					+ itoa(ivar_value(id_device_type))
					+ " DeviceRevision " 
					+ itoa(ivar_value(id_device_revision)) 
					+ " SoftwareRevision " 
					+ itoa(ivar_value(id_software_revision)) 
					+ " DeviceID "
					+ itoa(lvar_value(id_device_id)) 
					+ " TAG "
					+ sz1 ;

		_TRACE(szTrace) ;

		iassign(dd_manufacturer_id, GET_MANUFACTURER()) ;
		iassign(dd_device_type, GET_DEVICE_TYPE()) ;
		iassign(dd_device_revision, GET_DEVICE_REVISION()) ;
		
		szTrace = "Device expected: Man " 
					+ itoa(ivar_value(dd_manufacturer_id))
					+ " DeviceType "
					+ itoa(ivar_value(dd_device_type))
					+ " DeviceRevision " 
					+ itoa(ivar_value(dd_device_revision)) 
					+ " DeviceID "
					+ itoa(lDevice_Id) ;

		_TRACE(szTrace) ;

		
		iassign(dd_manufacturer_id, GET_MANUFACTURER()) ;
		iassign(dd_device_type, GET_DEVICE_TYPE()) ;
		iassign(dd_device_revision, GET_DEVICE_REVISION()) ;
		
		var_id[0] = VARID(dd_manufacturer_id) ;
		var_id[1] = VARID(dd_device_type) ;
		var_id[2] = VARID(dd_device_revision) ;
		var_id[3] = VARID(id_manufacturer_id) ;
		var_id[4] = VARID(id_device_type) ;
		var_id[5] = VARID(id_device_revision) ;
		var_id[6] = VARID(id_tag) ;

		if( (GET_MANUFACTURER() != 0) && (GET_MANUFACTURER() != 252) )
		{
			if( (ivar_value(id_manufacturer_id) != GET_MANUFACTURER())
				|| (ivar_value(id_device_type) != GET_DEVICE_TYPE())
				|| (ivar_value(id_device_revision) < ivar_value(dd_device_revision))
			 )
			{
				bOK = 0 ;
				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceTypeMismatch]) ;
				}
				else
				{
					put_message([DeviceTypeMismatch2], var_id) ;
				}
				process_abort() ;
			}
		}

		if( bOK && (lDevice_Id != 0) && (lDevice_Id != 1) )
		{
			if( id_device_id != lvar_value(device_id) )
			{
				var_id[0] = VARID(dd_manufacturer_id) ;
				var_id[1] = VARID(dd_device_type) ;
				var_id[2] = var_idDevice_Id ;
				var_id[3] = VARID(id_manufacturer_id) ;
				var_id[4] = VARID(id_device_type) ;
				var_id[5] = VARID(id_device_id) ;
				var_id[6] = VARID(id_tag) ;

				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceIdMismatch]) ;
				}
				else
				{
					acknowledge([DeviceIdMismatch2], var_id) ;
				}

				var_id[0] = var_idDevice_Id ;

				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceIdStore]) ;
				}
				else
				{
					acknowledge([DeviceIdStore], var_id) ;
				}

				if( VARID(device_id) != 0 )
				{
					lassign(device_id, lvar_value(id_device_id)) ;
				}
				else
				{
					lassign(final_assembly_number, lvar_value(id_device_id)) ;
				}
			}
			
			if( bOK )
			{
				sz1 = tag;
				
				if( id_tag != sz1 )
				{
					var_id[0] = VARID(tag) ;
					var_id[1] = VARID(id_tag) ;
				
					if (id_Method_In_SilentMode == 1)
					{
						LOG_MESSAGE(0, [TagMismatch2]) ;
					}
					else
					{
						acknowledge([TagMismatch2], var_id) ;
					}
				}
			}
		}

		ret_CheckDeviceIdentification	= ID_CHECK_SUCCESS ;
	}
}

#endif


#ifdef ENABLE_IDENTCHECK

METHOD	std_CheckDeviceIdentificationUpload
{
	LABEL		"IdentCheck Upload";
	CLASS		INPUT;
	ACCESS		OFFLINE;
	DEFINITION
	{
		int  iResult ;
		char szTrace[] ;
		char sz[] ;
		char sz1[] ;
		char sz2[] ;
		char sz3[] ;
		char sz4[] ;
		char sz5[] ;
		char szChoice[] ;
		long var_id[10] ;
		int bContinue ;
		int bOK ;
		int iChoice ;

		long lDevice_Id ;
		long var_idDevice_Id ;

		ret_CheckDeviceIdentification	= ID_CHECK_ABORT ;

		_TRACE("std_CheckDeviceIdentificationUpload") ;

		var_idDevice_Id = VARID(device_id) ;

		if( var_idDevice_Id != 0 )
		{
			lDevice_Id = lvar_value(device_id) ;
		}
		else
		{
			lDevice_Id = lvar_value(final_assembly_number) ;
			var_idDevice_Id = VARID(final_assembly_number) ;
			szTrace = "*** Rev 4 DD (final_assembly_number (VARID " 
						+ itoa(var_idDevice_Id)
						+ ") used) !" ;
			_TRACE(szTrace) ;
		}


		bOK = 1 ;

		iResult = ID_FC_ERROR;
		while (iResult >= ID_FC_ERROR)
		{
			id_command_num = COMMAND_ID_READ_UNIQUE_IDENTIFIER;
			iResult = ReadCommand(id_read_unique_identifier) ;
	
			if( iResult < ID_FC_ERROR )
			{
				id_command_num = COMMAND_ID_READ_TAG_DESCRIPTOR_DATE;
				iResult = ReadCommand(id_read_tag_descriptor_date);
			}
			id_command_num = id_command_num.DEFAULT_VALUE;

			if (iResult >= ID_FC_ERROR)
			{
				if (id_Method_In_SilentMode == 0)
					ACKNOWLEDGE([IdentCheckCommProblem]);
				else
					process_abort();
			}
		}


		sz1 = id_tag ;
		sz2 = itoa(ivar_value(id_write_protect)) ;
		szTrace = "Device found: Man " 
					+ itoa(ivar_value(id_manufacturer_id))
					+ " DeviceType "
					+ itoa(ivar_value(id_device_type))
					+ " DeviceRevision " 
					+ itoa(ivar_value(id_device_revision)) 
					+ " DeviceID "
					+ itoa(lvar_value(id_device_id)) 
					+ " TAG "
					+ sz1 ;

		_TRACE(szTrace) ;

		iassign(dd_manufacturer_id, GET_MANUFACTURER()) ;
		iassign(dd_device_type, GET_DEVICE_TYPE()) ;
		iassign(dd_device_revision, GET_DEVICE_REVISION()) ;
		
		szTrace = "Device expected: Man " 
					+ itoa(ivar_value(dd_manufacturer_id))
					+ " DeviceType "
					+ itoa(ivar_value(dd_device_type))
					+ " DeviceRevision " 
					+ itoa(ivar_value(dd_device_revision)) 
					+ " DeviceID "
					+ itoa(lDevice_Id) ;

		_TRACE(szTrace) ;
		
		var_id[0] = VARID(dd_manufacturer_id) ;
		var_id[1] = VARID(dd_device_type) ;
		var_id[2] = VARID(dd_device_revision) ;
		var_id[3] = VARID(id_manufacturer_id) ;
		var_id[4] = VARID(id_device_type) ;
		var_id[5] = VARID(id_device_revision) ;
		var_id[6] = VARID(id_tag) ;

		if( (GET_MANUFACTURER() != 0) && (GET_MANUFACTURER() != 252) )
		{
			if( (ivar_value(id_manufacturer_id) != GET_MANUFACTURER())
				|| (ivar_value(id_device_type) != GET_DEVICE_TYPE())
				|| (ivar_value(id_device_revision) < ivar_value(dd_device_revision))
			 )
			{
				bOK = 0 ;
				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceTypeMismatch]) ;
				}
				else
				{
					put_message([DeviceTypeMismatch2], var_id) ;
				}
				process_abort() ;
			}
		}

		if( bOK && (lDevice_Id != 0) && (lDevice_Id != 1) )
		{
			if( id_device_id != lDevice_Id )
			{
				var_id[0] = VARID(dd_manufacturer_id) ;
				var_id[1] = VARID(dd_device_type) ;
				var_id[2] = var_idDevice_Id ;
				var_id[3] = VARID(id_manufacturer_id) ;
				var_id[4] = VARID(id_device_type) ;
				var_id[5] = VARID(id_device_id) ;
				var_id[6] = VARID(id_tag) ;

				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceIdMismatch2]) ;
					process_abort();
				}
				else
				{
					acknowledge([DeviceIdMismatch2], var_id) ;
				}

				var_id[0] = var_idDevice_Id ;


				if (id_Method_In_SilentMode == 0)
				{
					acknowledge([DeviceIdStore], var_id) ;
				}

				if( VARID(device_id) != 0 )
				{
					lassign(device_id, lvar_value(id_device_id)) ;
				}
				else
				{
					lassign(final_assembly_number, lvar_value(id_device_id)) ;
				}
			}
		}
		else
		{
			if( VARID(device_id) != 0 )
			{
				lassign(device_id, lvar_value(id_device_id)) ;
			}
			else
			{
				lassign(final_assembly_number, lvar_value(id_device_id)) ;
			}
		}

#ifdef CHECK_SOFTWARE_REVISION
		if( bOK )
		{
			if( software_revision > id_software_revision )
			{
				var_id[0] = VARID(id_software_revision) ;
				var_id[1] = VARID(software_revision) ;

				if (id_Method_In_SilentMode == 0)
				{
					acknowledge([SoftwareRevisionToLow], var_id) ;
				}

				// user clicked 'OK': store new software_revision in offline data
				iassign(software_revision, ivar_value(id_software_revision)) ;
			}
		}
#endif

		if( bOK )
		{
			if( id_tag != tag )
			{
				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [TagMismatch]) ;
				}
				else
				{
					get_dictionary_string(cancel, sz1) ;
					get_dictionary_string(TagMismatch_keep_old, sz2) ;
					get_dictionary_string(TagMismatch_apply, sz3) ;

					sz4 = tag ;
					sz5 = id_tag ;
					sz = sz1
						+ ";"
						+ sz2
						+ " (" 
						+ sz4 
						+ ")" 
						+ ";" 
						+ sz3
						+ " (" 
						+ sz5 
						+ ")" ;

								
					iChoice = SELECT_FROM_LIST([TagMismatch], sz) ;

					switch (iChoice)
					{
						case 0:						// abort
							bOK = 0 ;
							break;

						case 1:						// keep old
							break;

						default:					// use new
							tag = id_tag ;
							break;
					}
				}
			}
		}

		if( bOK )
		{
			ret_CheckDeviceIdentification	= ID_CHECK_SUCCESS ;
			_TRACE("IdentCheck was succesful !") ;
		}
	}
}

#endif



#ifdef ENABLE_IDENTCHECK

METHOD	std_CheckDeviceIdentificationDownload
{
	LABEL		"IdentCheck Download";
	CLASS		INPUT;
	ACCESS		OFFLINE;
	DEFINITION
	{
		int  iResult ;
		char szTrace[] ;
		char sz[] ;
		char sz1[] ;
		char sz2[] ;
		char sz3[] ;
		char sz4[] ;
		char sz5[] ;
		char szChoice[] ;
		long var_id[10] ;
		int bContinue ;
		int bOK ;
		long lDevice_Id ;
		long var_idDevice_Id ;

		ret_CheckDeviceIdentification	= ID_CHECK_ABORT ;

		_TRACE("std_CheckDeviceIdentificationDownload") ;

		var_idDevice_Id = VARID(device_id) ;

		if( var_idDevice_Id != 0 )
		{
			lDevice_Id = lvar_value(device_id) ;
		}
		else
		{
			lDevice_Id = lvar_value(final_assembly_number) ;
			var_idDevice_Id = VARID(final_assembly_number) ;
			szTrace = "*** Rev 4 DD (final_assembly_number (VARID " 
						+ itoa(var_idDevice_Id)
						+ ") used) !" ;
			_TRACE(szTrace) ;
		}

		bOK = 1 ;

		id_command_num = COMMAND_ID_READ_UNIQUE_IDENTIFIER;
		iResult = ReadCommand(id_read_unique_identifier) ;

		if( iResult < ID_FC_ERROR )
		{
			id_command_num = COMMAND_ID_READ_TAG_DESCRIPTOR_DATE;
			iResult = ReadCommand(id_read_tag_descriptor_date);
		}
		id_command_num = id_command_num.DEFAULT_VALUE;


		if (id_Method_In_SilentMode == 0)
		{
			while( iResult >= ID_FC_ERROR )
			{
				ACKNOWLEDGE([IdentCheckCommProblem]) ;
		
				id_command_num = COMMAND_ID_READ_UNIQUE_IDENTIFIER;
				iResult = ReadCommand(id_read_unique_identifier) ;

				if( iResult < ID_FC_ERROR )
				{
					id_command_num = COMMAND_ID_READ_TAG_DESCRIPTOR_DATE;
					iResult = ReadCommand(id_read_tag_descriptor_date);
				}
				id_command_num = id_command_num.DEFAULT_VALUE;
			}
		}

		sz1 = id_tag ;
		szTrace = "Device found: Man " 
					+ itoa(ivar_value(id_manufacturer_id))
					+ " DeviceType "
					+ itoa(ivar_value(id_device_type))
					+ " DeviceRevision " 
					+ itoa(ivar_value(id_device_revision)) 
					+ " DeviceID "
					+ itoa(lvar_value(id_device_id)) 
					+ " TAG "
					+ sz1 ;

		_TRACE(szTrace) ;

		iassign(dd_manufacturer_id, GET_MANUFACTURER()) ;
		iassign(dd_device_type, GET_DEVICE_TYPE()) ;
		iassign(dd_device_revision, GET_DEVICE_REVISION()) ;
		
		szTrace = "Device expected: Man " 
					+ itoa(ivar_value(dd_manufacturer_id))
					+ " DeviceType "
					+ itoa(ivar_value(dd_device_type))
					+ " DeviceRevision " 
					+ itoa(ivar_value(dd_device_revision)) 
					+ " DeviceID "
					+ itoa(lDevice_Id) ;

		_TRACE(szTrace) ;

		var_id[0] = VARID(dd_manufacturer_id) ;
		var_id[1] = VARID(dd_device_type) ;
		var_id[2] = VARID(dd_device_revision) ;
		var_id[3] = VARID(id_manufacturer_id) ;
		var_id[4] = VARID(id_device_type) ;
		var_id[5] = VARID(id_device_revision) ;
		var_id[6] = VARID(id_tag) ;

		if( (GET_MANUFACTURER() != 0) && (GET_MANUFACTURER() != 252) )
		{
			if( (ivar_value(id_manufacturer_id) != GET_MANUFACTURER())
				|| (ivar_value(id_device_type) != GET_DEVICE_TYPE())
				|| (ivar_value(id_device_revision) < ivar_value(dd_device_revision))
			 )
			{
				bOK = 0 ;
				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceTypeMismatch]) ;
				}
				else
				{
					put_message([DeviceTypeMismatch2], var_id) ;
				}
				process_abort() ;
			}
		}

		if( bOK && (lDevice_Id != 0) && (lDevice_Id != 1) )
		{
			if( id_device_id != lDevice_Id )
			{
				var_id[0] = VARID(dd_manufacturer_id) ;
				var_id[1] = VARID(dd_device_type) ;
				var_id[2] = var_idDevice_Id ;
				var_id[3] = VARID(id_manufacturer_id) ;
				var_id[4] = VARID(id_device_type) ;
				var_id[5] = VARID(id_device_id) ;
				var_id[6] = VARID(id_tag) ;

				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [DeviceIdMismatch2]) ;
				}
				else
				{
					acknowledge([DeviceIdMismatch2], var_id) ;
				}

				var_id[0] = var_idDevice_Id ;

				if (id_Method_In_SilentMode == 0 )
				{
					acknowledge([DeviceIdStore], var_id) ;
				}
			}
		}

		if( bOK )
		{
			bContinue = 0 ;
			sz1 = tag;
			
			if( id_tag != sz1 )
			{
				var_id[0] = VARID(tag) ;
				var_id[1] = VARID(id_tag) ;
			
				if (id_Method_In_SilentMode == 1)
				{
					LOG_MESSAGE(0, [TagMismatch]) ;
				}
				else
				{
					acknowledge([TagMismatch2], var_id) ;
				}
			}
		}

		if( bOK )
		{
			ret_CheckDeviceIdentification	= ID_CHECK_SUCCESS ;
			_TRACE("IdentCheck was succesful !") ;
		}
	}
}

#endif



// --- Checking Write Protection ------------------------------------------

#define	ID_CHECK_WRITABLE			0
#define	ID_CHECK_WRITE_PROTECTED	1

VARIABLE	ret_CheckWriteProtection
{
	LABEL		"Write Protection Result";
	CLASS		LOCAL;
	TYPE		UNSIGNED_INTEGER (1)
	{
		DEFAULT_VALUE	ID_CHECK_WRITABLE ;
	}
	HANDLING	READ;
}


#ifdef ENABLE_WRITEPROTECTIONCHECK
METHOD	std_CheckWriteProtection
{
	LABEL		"std_CheckWriteProtection";
	CLASS		INPUT;
	ACCESS		OFFLINE;
	DEFINITION
	{
		long var_id[10] ;
		int  iResult ;
		char szTrace[] ;
		char sz[] ;

		ret_CheckWriteProtection = ID_CHECK_WRITABLE ;

		_TRACE("std_CheckWriteProtection") ;

		id_command_num = COMMAND_ID_READ_PV_OUTPUT_INFO;
		iResult = ReadCommand(id_read_pv_output_info);
		id_command_num = id_command_num.DEFAULT_VALUE;
		if( iResult >= ID_FC_ERROR )
		{
			iassign(id_write_protect, 252) ;
		}

		sz = itoa(ivar_value(id_write_protect)) ;
		szTrace = "Write protect = " + sz ;

		_TRACE(szTrace) ;


		if( id_write_protect == 1 )
		{
			ret_CheckWriteProtection = ID_CHECK_WRITE_PROTECTED ;

			id_command_num = COMMAND_ID_READ_TAG_DESCRIPTOR_DATE;
			iResult = ReadCommand(id_read_tag_descriptor_date);
			id_command_num = id_command_num.DEFAULT_VALUE;

			var_id[0] = VARID(id_manufacturer_id) ;
			var_id[1] = VARID(id_device_type) ;
			var_id[2] = VARID(id_tag) ;

			if (id_Method_In_SilentMode == 1)
			{
				LOG_MESSAGE(0, [DeviceWriteProtected]) ;
			}
			else
			{
				acknowledge([DeviceWriteProtected], var_id) ;
			}
			
			// user clicked 'OK' so write to device anyway ...
			ret_CheckWriteProtection = ID_CHECK_WRITABLE ;
		}

	}
}
#endif



/*******************************************************************************/
/*****	Commands  **************************************************************/
/*******************************************************************************/

VARIABLE	id_command_num
{
	LABEL		"Command Number";
	CLASS		LOCAL;
	TYPE		INTEGER (2)
	{
		DEFAULT_VALUE	-1;
	}
	HANDLING	READ;
}

COMMAND id_read_unique_identifier
{
	NUMBER id_command_num;				// NUMBER 0
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			response_code, 
			device_status,
			254, 
			id_manufacturer_id, 
			id_device_type,  
			id_dummy_byte, 
			id_dummy_byte, 
			id_device_revision, 
			id_software_revision,
			id_dummy_byte, 
			id_dummy_byte, 
			id_device_id 
		}
	}
	RESPONSE_CODES
	{
		0,	SUCCESS,	[no_command_specific_errors];
		6,	MISC_ERROR,	[xmtr_specific_command_error];
		16,	MODE_ERROR,	[access_restricted];
	}
}

COMMAND id_read_tag_descriptor_date
{
	NUMBER id_command_num;				// NUMBER 13
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			response_code, device_status, id_tag	//, id_descriptor, id_date
		}
	}
	RESPONSE_CODES
	{
		0,	SUCCESS,	[no_command_specific_errors];
		6,	MISC_ERROR, [xmtr_specific_command_error];
		16,	MODE_ERROR, [access_restricted];
	}
}



COMMAND id_read_pv_output_info
{
	NUMBER id_command_num;				// NUMBER 15
	OPERATION READ;
	TRANSACTION
		{
			REQUEST
				{}

			REPLY
				{
					response_code, device_status,
					id_dummy_byte, id_dummy_byte,
					id_dummy_byte, id_dummy_float, id_dummy_float,
					id_dummy_float, id_write_protect, id_dummy_byte
				}
		}

	RESPONSE_CODES
		{
			0,	SUCCESS,	[no_command_specific_errors];
			6,	MISC_ERROR, [xmtr_specific_command_error];
			16,	MODE_ERROR, [access_restricted];
		}
}

